/*******************************************************************@CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*     Licensed Materials - Property of IBM                         @CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*     5622-078                                                     @CM2CPYR*/
/*     (C) Copyright IBM Corp. 1988, 1995 All Rights Reserved.      @CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*     US Government Users Restricted Rights - Use, duplication or  @CM2CPYR*/
/*     disclosure restricted by GSA ADP Schedule Contract with      @CM2CPYR*/
/*     IBM Corp.                                                    @CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*******************************************************************@CM2CPYR*/
#ifdef __cplusplus
  extern "C" {
#endif

#ifndef  ACSMGTC_INCLUDED
#define  ACSMGTC_INCLUDED
#ifndef  APPCDEF_INCLUDED
#include <appcdef.h>
#endif

/****************************************************************************/
/*      Management Verb Control Blocks                                      */
/****************************************************************************/

/* Mask for the CNOS field: select_type                                     */
#define AP_CNOS_MODE_NAME_SELECT_ALL 0x0001
#define AP_CNOS_SET_NEGOTIABLE       0x0002

/* Mask for the CNOS field: termination_settings                            */
#define AP_CNOS_DRAIN_TARGET       0x0001
#define AP_CNOS_DRAIN_SOURCE       0x0002
#define AP_CNOS_RESPONSIBLE_TARGET 0x0004

typedef struct cnos32 {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_CNOS                        */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  lu_alias[8];                /* LU Alias (ASCII)                  */
                                       /*    0 or 1-8 bytes                 */
    UCHAR  plu_alias[8];               /* Partner LU Alias (ASCII)          */
                                       /*    0 or 1-8 bytes                 */
    UCHAR  fqplu_name[17];             /* FQ Partner LU Name (EBCDIC type A)*/
                                       /*    0-17 bytes                     */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  mode_name[8];               /* Mode Name (EBCDIC type A)         */
                                       /*    0-8 bytes                      */
    UCHAR  reserv5[2];                 /*                                   */
    USHORT select_type;                /* Mode Name select                  */
                                       /*    and set negotiable flags       */
    UCHAR  reserv6[2];                 /* Reserved                          */
    USHORT plu_mode_sess_lim;          /* Partner LU mode session limit     */
                                       /*    0-32767                        */
    USHORT min_conwinners_source;      /* Minimum contention winners source */
                                       /*    0-32767                        */
    USHORT min_conwinners_target;      /* Minimum contention winners target */
                                       /*    0-32767                        */
    USHORT auto_act;                   /* Auto Activate                     */
                                       /*    0-32767                        */
    USHORT termination_settings;       /* Drain and Responsible settings    */
    UCHAR  reserv8[2];                 /* Reserved -- pack4 alignment       */
    ULONG  sense_data;                 /* Sense Data                        */
    UCHAR  reserv7[28];               /* Reserved                          */
} CNOS32;


/* This structure, CNOS, should only be used for migration of 16 bit code   */
/* to 32 bit code.  Otherwise the structure CNOS32,  given above,           */
/* should be used.  That structures uses masks, rather than                 */
/* explicit bit fields, to access the select_type and                       */
/* termination_settings, and is more reliable for code portability.         */
typedef struct cnos {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_CNOS                        */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  lu_alias[8];                /* LU Alias (ASCII)                  */
                                       /*    0 or 1-8 bytes                 */
    UCHAR  plu_alias[8];               /* Partner LU Alias (ASCII)          */
                                       /*    0 or 1-8 bytes                 */
    UCHAR  fqplu_name[17];             /* FQ Partner LU Name (EBCDIC type A)*/
                                       /*    0-17 bytes                     */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  mode_name[8];               /* Mode Name (EBCDIC type A)         */
                                       /*    0-8 bytes                      */
    UCHAR  reserv5[2];                 /*                                   */
    UINT   mode_name_select:1;         /* Bit 7                             */
                                       /* Mode name select                  */
                                       /*    AP_ONE                         */
                                       /*    AP_ALL                         */
    UINT   set_negotiable:1;           /* Bit 6                             */
                                       /* Set negotiable?                   */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   reserv6:6;                  /* Bits 0-5                          */
                                       /*                                   */
    UINT   reserv7:8;                  /* Bits 8-15                         */
                                       /*                                   */
    UCHAR  reserv8[2];                 /* Reserved                          */
    USHORT plu_mode_sess_lim;          /* Partner LU mode session limit     */
                                       /*    0-32767                        */
    USHORT min_conwinners_source;      /* Minimum contention winners source */
                                       /*    0-32767                        */
    USHORT min_conwinners_target;      /* Minimum contention winners target */
                                       /*    0-32767                        */
    USHORT auto_act;                   /* Auto Activate                     */
                                       /*    0-32767                        */
    UINT   drain_target:1;             /* Bit 15                            */
                                       /* Drain Target?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   drain_source:1;             /* Bit 14                            */
                                       /* Drain Source?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   responsible:1;              /* Bit 13                            */
                                       /* Responsible?                      */
                                       /*    AP_SOURCE                      */
                                       /*    AP_TARGET                      */
    UINT   reserv9:5;                  /* Bits 8-12                         */
                                       /* Reserved                          */
    UINT   reserv10:8;                  /* Bit 0-7                           */
                                       /* Reserved                          */
    UCHAR  reserv11[34];               /* Reserved                          */
} CNOS;

typedef struct connect_physical_link {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_CONNECT_PHYSICAL_LINK       */
    UCHAR  reserv2[2];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv3[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  reserv4[8];                 /* Reserved                          */
    UCHAR  physical_link_name[8];      /* Physical Link Name                */
    UCHAR  connection_type;            /* Connection Type                   */
                                       /*    AP_LINK_CONNECT                */
                                       /*    AP_LINK_AUTO_CONNECT           */
    UCHAR  reserv5[24];                /* Reserved                          */
} CONNECT_PHYSICAL_LINK;

typedef struct activate_dlc {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_ACTIVATE_DLC                */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  dlc_name[8];                /* DLC name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC adapter number                */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  reserv5[2];                 /* Reserved                          */
    ULONG  adapter_failure_rc;         /* Adapter Failure RETURN CODE       */
    UCHAR  reserv6[28];                /* Reserved                          */
} ACTIVATE_DLC;

typedef struct deactivate_dlc {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_DEACTIVATE_DLC              */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  dlc_name[8];                /* DLC name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC adapter number                */
    UCHAR  reserv4[35];                /* Reserved                          */
} DEACTIVATE_DLC;

typedef struct activate_logical_links {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_ACTIVATE_LOGICAL_LINKS      */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  link_name[8];               /* Link Name (EBCDIC type A)         */
    UCHAR  number_of_links;            /* Number of Links to Start          */
                                       /*    AP_ACTIVATE_ONE                */
                                       /*    AP_ACTIVATE_ALL                */
    UCHAR  reserv5;                    /* Reserved                          */
    USHORT link_failure_rc;            /* Return code from ACSAPPC          */
    ULONG sense_data;                  /* Sense Data                        */
    UCHAR  reserv4[28];                /* Reserved                          */
} ACTIVATE_LOGICAL_LINKS;


typedef struct deactivate_logical_link {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_DEACTIVATE_LOGICAL_LINK     */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  link_id[12];                /* Link ID                           */
    UCHAR  type;                       /* Type of link                      */
                                       /*    AP_LINK_HARD                   */
                                       /*    AP_LINK_SOFT                   */
    UCHAR  reserv4[35];                /* Reserved                          */
} DEACTIVATE_LOGICAL_LINK;


typedef struct deactivate_conv_group {
    USHORT opcode;                     /* Verb operation code               */
                                       /*   AP_DEACTIVATE_CONV_GROUP        */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  lu_alias[8];                /* LU Alias (ASCII) 0 or 1-8 bytes   */
    ULONG  conv_group_id;              /* Conversation Group ID             */
    UCHAR  type;                       /* Type of Deactivate                */
                                       /*    AP_DEACT_CLEANUP               */
                                       /*    AP_DEACT_NORMAL                */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  sense_data[4];              /* Sense data returned               */
    UCHAR  reserv5[34];                /* Reserved                          */
} DEACTIVATE_CONV_GROUP;


typedef struct deactivate_session {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_DEACTIVATE_SESSION          */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  sess_id[8];                 /* Session ID                        */
    UCHAR  lu_alias[8];                /* LU Alias (ASCII)                  */
                                       /*    0 or 1-8 bytes                 */
    UCHAR  plu_alias[8];               /* Partner LU Alias (ASCII)          */
                                       /*    0 or 1-8 bytes                 */
    UCHAR  mode_name[8];               /* Mode Name (EBCDIC type A)         */
                                       /*    0-17 bytes                     */
    UCHAR  type;                       /* Type of Deactivate                */
                                       /*    AP_DEACT_CLEANUP               */
                                       /*    AP_DEACT_NORMAL                */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  sense_data[4];              /* Sense data returned               */
    UCHAR  fqplu_name[17];             /* FQ Partner LU Name (EBCDIC type A)*/
                                       /*    0-17 bytes                     */
    UCHAR  reserv5[33];                /* Reserved                          */
} DEACTIVATE_SESSION;


typedef struct disconnect_physical_link {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_DISCONNECT_PHYSICAL_LINK    */
    UCHAR  reserv2[2];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv3[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  reserv4[8];                 /* Reserved                          */
    UCHAR  physical_link_name[8];      /* Physical Link Name                */
    UCHAR  reserv5[24];                /* Reserved                          */
} DISCONNECT_PHYSICAL_LINK;


typedef struct start_am {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_START_AM                    */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  reserv4[32];                /* Reserved                          */
} START_AM;


typedef struct stop_am {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_STOP_AM                     */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  reserv4[32];                /* Reserved                          */
} STOP_AM;

typedef struct accept_incoming_calls {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_ACCEPT_INCOMING_CALLS       */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  icrt_name[16];              /* ICRT entry name (ASCII)           */
    UCHAR  reserv4[32];                /* Reserved                          */
} ACCEPT_INCOMING_CALLS;

typedef struct reject_incoming_calls {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_REJECT_INCOMING_CALLS       */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  key[8];                     /* Key (ASCII)                       */
    UCHAR  icrt_name[16];              /* ICRT entry name (ASCII)           */
    UCHAR  reserv4[32];                /* Reserved                          */
} REJECT_INCOMING_CALLS;

typedef struct psid_struct             /* Product set id structure          */
{
    UCHAR  machine_type[4];            /* Machine type                      */
    UCHAR  machine_mod_num[3];         /* Machine model number              */
    UCHAR  plant_of_mfg[2];            /* IBM manufacturing plant           */
    UCHAR  machine_seq_num[7];         /* Machine sequence number           */
} type_product_set_id;


typedef struct sna_global_info_sect {   /* One of these                     */

  /**************************************************************************/
  /* The address of this structure should be: sna_global_info_ptr           */
  /**************************************************************************/

    UCHAR  cfg_version;                /* Comm Manager config version       */
    UCHAR  cfg_release;                /* Comm Manager config release       */
    UCHAR  net_name[8];                /* NETID (EBCDIC type A)             */
    UCHAR  pu_name[8];                 /* PU name (EBCDIC type A)           */
    UCHAR  node_id[4];                 /* Node ID used in XID               */
    type_product_set_id product_set_id;/* Product Set ID                    */
    UCHAR  alias_cp_name[8];           /* Alias CP Name (ASCII)             */
    UCHAR  node_type;                  /* Node Type                         */
                                       /*    AP_NN                          */
                                       /*    AP_EN                          */
    UCHAR  cp_nau_addr;                /* CP NAU Address                    */
                                       /*  0 (not used...independent LU) OR */
                                       /*  1-254                            */
    UCHAR  cfg_corr_serv_disk;         /* reserved for config serv #        */
    UCHAR  reserv3;                    /* reserved                          */
    UCHAR  version;                    /* Communications Server version     */
    UCHAR  release;                    /* Communications Server release     */
    USHORT corr_serv_disk;             /* Comm Server corrective service    */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} SNA_GLOBAL_INFO_SECT;



typedef struct lu62_info_sect {        /* One of these                      */
  /**************************************************************************/
  /* The address of this structure should be: lu62_info_ptr                 */
  /**************************************************************************/

    ULONG  lu62_init_sect_len;         /* Structure length                  */
    USHORT num_lu62s;                  /* Number of active LUs displayed    */
    USHORT total_lu62s;                /* Total Number of active LUs        */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/
} LU62_INFO_SECT;

typedef struct lu62_overlay {          /* One for each LU                   */

  /**************************************************************************/
  /* The address of the first of these structures should be: lu62_info_ptr +*/
  /* lu62_info_ptr->lu62_init_sect_len to find the next LU, add:            */
  /* lu62_entry_len                                                         */
  /**************************************************************************/

    ULONG  lu62_entry_len;             /* Size of this LU entry             */
    ULONG  lu62_overlay_len;           /* This value contains:              */
                                       /*    sizeof(struct lu62_overlay) -  */
                                       /*    sizeof(lu62_entry_len)         */
    UCHAR  lu_name[8];                 /* LU Name (EBCDIC type A)           */
    UCHAR  lu_alias[8];                /* LU Alias (ASCII)                  */
    USHORT num_plus;                   /* Number of partner LUs             */
    UCHAR  fqlu_name[17];              /* Fully Qualified LU Name           */
                                       /*    (EBCDIC type A)                */
    UCHAR  default_lu;                 /* Default LU?                       */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  lu_local_addr;              /* NAU address 0-254                 */
    USHORT lu_sess_lim;                /* Configured session limit          */
                                       /*    0-255                          */
    UCHAR  max_tps;                    /* Max number of TPs 1-255           */
    UCHAR  lu_type;                    /* LU type (X'06') OR'd with type of */
                                       /* support for external services     */
                                       /*  associated with this LU:         */
                                       /*    AP_NONE                        */
                                       /*    AP_REMOTE_TP_PROVIDER          */
                                       /*    AP_SYNCPT_PROVIDER             */
                                       /*    (AP_SYNCPT_PROVIDER |          */
                                       /*     AP_REMOTE_TP_PROVIDER)        */
    UCHAR  pu_name[8];                 /* PU Name (EBCDIC type A)           */
    UCHAR  syncpt_mgr_name[16];        /* Syncpoint Provider Name           */
                                       /* ASCII name provided               */
                                       /* if lu_type field includes         */
                                       /* SYNCPT_PROVIDER;                  */
                                       /* otherwise binary zeros.           */
    UCHAR  remote_tp_mgr_name[16];     /* Remote TP Provider Name           */
                                       /* ASCII name provided               */
                                       /* if lu_type field includes         */
                                       /* REMOTE_TP_PROVIDER;               */
                                       /* otherwise binary zeros.           */
    UCHAR  fq_host_known_luname[17];   /* LU name as known at the host      */
    UCHAR  lu_model_name[7];           /* LU model name                     */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LU62_OVERLAY;

typedef struct plu62_overlay {         /* One for each partner LU           */

  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the current lu62_overlay + lu62_overlay_len + sizeof(lu62_entry_len)   */
  /* To find the next partner LU, add: plu62_entry_len.                     */
  /**************************************************************************/

    ULONG  plu62_entry_len;            /* Size of this partner LU           */
    ULONG  plu62_overlay_len;          /* This value contains:              */
                                       /*    sizeof(struct plu62_overlay) - */
                                       /*    sizeof(plu62_entry_len)        */
    UCHAR  plu_alias[8];               /* Partner LU Alias (ASCII)          */
    USHORT num_modes;                  /* Number of modes                   */
    UCHAR  plu_un_name[8];             /* Partner LU Uninterpreted Name     */
                                       /*    (EBCDIC)                       */
    UCHAR  fqplu_name[17];             /* Fully Qualified Partner LU Name   */
                                       /*    (EBCDIC type A)                */
    UCHAR  reserv3;                    /* Reserved                          */
    USHORT plu_sess_lim;               /* Partner LU session limit          */
    UCHAR  dlc_name[8];                /* DLC name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC adapter number                */
    UCHAR  dest_addr_len;              /* Length of adapter addr            */
    UCHAR  dest_addr[32];              /* Destination adapter addr          */
    UINT   par_sess_supp:1;            /* Bit 15  Parallel sessions?        */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   reserv4:7;                  /* Bits 8-14  Reserved               */
    UINT   def_already_ver:1;          /* Bit 7  Configured already verif?  */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   def_conv_sec:1;             /* Bit 6  Configured conv security?  */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   def_sess_sec:1;             /* Bit 5  Configured session security*/
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   reserv5:5;                  /* Bits 0-4  Reserved                */
    UINT   act_already_ver:1;          /* Bit 15  Active already verified?  */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   act_conv_sec:1;             /* Bit 14  Active conversation sec?  */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   reserv6:6;                  /* Bits 8-13  Reserved               */
    UINT   implicit_part:1;            /* Bit 7  Implicit partner?          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   reserv7:7;                  /* Bits 0-6  Reserved                */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} PLU62_OVERLAY;

typedef struct mode_overlay {          /* One for each mode                 */

  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the current plu62_overlay + plu62_overlay_len + sizeof(plu62_entry_len)*/
  /* To find the next mode, add: mode_entry_len.                            */
  /**************************************************************************/

    ULONG  mode_entry_len;             /* Size of this mode                 */
    UCHAR  mode_name[8];               /* Mode Name (EBCDIC type A)         */
    USHORT max_ru_size_upp;            /* Upper Limit on Max RU             */
    USHORT max_ru_size_low;            /* Lower Limit on Max RU             */
    USHORT max_neg_sess_lim;           /* Max Limit on Sessions             */
    USHORT curr_sess_lim;              /* Current Session Limit             */
    USHORT min_win_lim;                /* Min Negotiated Winners            */
    USHORT min_lose_lim;               /* Min Negotiated Losers             */
    USHORT act_sess_count;             /* Active Session Count              */
    USHORT pend_sess_count;            /* Pending Session Count             */
    USHORT auto_act_sess_count;        /* Auto Activate Session Count       */
    USHORT act_win_lim;                /* Active Winner Sessions            */
    USHORT act_lose_lim;               /* Active Loser Sessions             */
    USHORT term_count;                 /* Session Termination Count         */

    UINT   drain_target:1;             /* Bit 15  Drain Target?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   drain_source:1;             /* Bit 14  Drain Source?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   reserv3:6;                  /* Bits 8-13  Reserved               */
    UINT   pacing_size:8;              /* Bits 0-7  Pacing size             */
    /* The preceeding fields were previously defined as "unsigned char".    */
    /* They have been integrated into a bitfield to eliminate warning       */
    /* messages about 'bitfield types other than int'.                      */

    UINT   implicit_mode:1;            /* Bit 15  Implicit Mode?            */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   reserv4:7;                  /* Bits 8-14  Reserved               */
    UINT   reserv5:8;                  /* Bits 0-7  Reserved                */
    UCHAR  def_compression_need ;      /* Defined compression need          */
                                       /* for the mode. SYSTEM,             */
                                       /* REQUESTED or PROHIBITED           */
    UCHAR  def_plu_slu_compression ;   /* plu to slu defined                */
                                       /* compression algorithm             */
                                       /* NONE, RLE, or LZ9                 */
    UCHAR  def_slu_plu_compression ;   /* slu to plu defined                */
                                       /* compression algorithm             */
                                       /* NONE, RLE, or LZ9                 */

    /************************************************************************/
    /* Reserved Additional fields may be added here in future releases      */
    /************************************************************************/

} MODE_OVERLAY;

typedef struct am_info_sect {          /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: am_info_ptr                   */
  /**************************************************************************/

    ULONG  am_init_sect_len;           /* Structure length                  */
    UCHAR  am_active;                  /* Attach Manager active?            */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv4;                    /* Reserved                          */
    USHORT num_tps;                    /* Number of configured TPs displayed*/
    USHORT total_tps;                  /* Total Number of configured TPs    */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} AM_INFO_SECT;

typedef struct am_overlay {            /* One for each configued TP         */

  /**************************************************************************/
  /* The address of the first of these structures should be: am_info_ptr +  */
  /* am_info_ptr->am_init_sect_len. To find the next block of TP,           */
  /* information, add: am_entry_len.                                        */
  /**************************************************************************/


    ULONG  am_entry_len;               /* Size of this structure            */
    UCHAR  tp_name[64];                /* TP name (EBCDIC type AE)          */
    UCHAR  filespec[64];               /* TP filespec (ASCII)               */

    UINT   reserv3:1;                  /* Bit 15  Reserved                  */
    UINT   sync_level_conf:1;          /* Bit 14  Sync Level (Confirm) ?    */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   sync_level_none:1;          /* Bit 13  Sync Level (None) ?       */
                                       /*    AP_NOT_SUPPORTED               */
                                       /*    AP_SUPPORTED                   */
    UINT   reserv4:5;                  /* Bits 8-12  Reserved               */
    UINT   conv_type:8;                /* Bits 0-7  Conversation type       */
                                       /*    AP_BASIC_CONVERSATION          */
                                       /*    AP_MAPPED_CONVERSATION         */
                                       /*    AP_EITHER                      */
                                       /*    AP_FDX_BASIC_CONVERSATION      */
                                       /*    AP_FDX_MAPPED_CONVERSATION     */
                                       /*    AP_FDX_EITHER                  */
                                       /*    AP_ANY_TYPE                    */
    /* The preceeding fields were previously defined as "unsigned char".    */
    /* They have been integrated into a bitfield to eliminate warning       */
    /* messages about 'bitfield types other than int'.                      */

    USHORT in_all_qdpth_lim;           /* Incoming Allocate queue depth lim */
    USHORT in_all_qdpth;               /* Incoming Allocate queue depth     */
    short  in_all_timeout;             /* Incoming Allocate t/o             */
                                       /*    AP_HOLD_FOREVER or time in sec */
    USHORT num_rcv_all_pend;           /* Number of pending                 */
                                       /* RECEIVE_ALLOCATEs                 */
    short  rcv_all_timeout;            /* RECEIVE_ALLOCATE t/o              */
                                       /*    AP_HOLD_FOREVER or time in sec */
    UCHAR  tp_type;                    /* TP type                           */
                                       /*    AP_QUEUED_OPERATOR_STARTED     */
                                       /*    AP_QUEUED_AM_STARTED           */
                                       /*    AP_NONQUEUED_AM_STARTED        */
                                       /*    AP_QUEUED_OPERATOR_PRELOADED   */
    UCHAR  pgm_state;                  /* Program state                     */
                                       /*    AP_INACTIVE                    */
                                       /*    AP_LOADED                      */
                                       /*    AP_LOADING                     */
                                       /*    AP_RUNNING                     */
    UCHAR  conv_sec;                   /* Conversation security?            */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv5;                    /* Reserved                          */
    USHORT process_id;                 /* OS/2 process ID                   */
    UCHAR  parm_string[32];            /* Pgm parameter string              */
    UCHAR  program_type;               /* Program Type                      */
                                       /*    AP_BACKGROUND                  */
                                       /*    AP_FULL_SCREEN                 */
                                       /*    AP_PRESENTATION_MANAGER        */
                                       /*    AP_VIO_WINDOWABLE              */
    UCHAR  reserv5a;                   /* Reserved                          */
    UCHAR  tp_initiated;               /* TP initiated                      */
                                       /*    AP_LOCALLY                     */
                                       /*    AP_REMOTELY                    */
    UCHAR  reserv6;                    /* Reserved                          */
    UCHAR  icon_filespec[80];          /* Icon Filespec (ASCII)             */
    ULONG  wildcard;                   /* Wildcard Type                     */
                                       /*    AP_NO_WILDCARD                 */
                                       /*    AP_PARTIAL_WILDCARD            */
                                       /*    AP_FULL_WILDCARD               */
    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} AM_OVERLAY;

typedef struct tp_info_sect {          /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: tp_info_ptr                   */
  /**************************************************************************/

    ULONG  tp_init_sect_len;           /* Structure length                  */
    USHORT num_tps;                    /* Number of active TPs displayed    */
    USHORT total_tps;                  /* Total Number of Active TPs        */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} TP_INFO_SECT;

typedef struct tp_overlay {            /* One for each active TP            */

  /**************************************************************************/
  /* The address of the first of these structures should be: tp_info_ptr +  */
  /* tp_info_ptr->tp_init_sect_len.  To find the next block of active TP    */
  /* information, add: tp_entry_len                                         */
  /**************************************************************************/


    ULONG  tp_entry_len;               /* Size of this TP record            */
    ULONG  tp_overlay_len;             /* This value contains:              */
                                       /*    sizeof(struct tp_overlay) -    */
                                       /*    sizeof(tp_entry_len)           */
    USHORT num_conv;                   /* Number of conversations           */
    UCHAR  tp_id[8];                   /* TP ID                             */
    UCHAR  tp_name[64];                /* TP name (EBCDIC type AE)          */
    UCHAR  user_id[10];                /* User ID (EBCDIC type AE)          */
    UINT   reserv3:7;                  /* Bits 9-15 Reserved                */
    UINT   loc_or_rem:1;               /* Bit 8  Initiated local or remote? */
                                       /*    AP_LOCAL                       */
                                       /*    AP_REMOTE                      */
    UINT   reserv4:8;                  /* Bits 0-7 Reserved                 */
    UCHAR  lu_alias[8];                /* LU_ALIAS (ASCII)                  */
    LUW_ID_OVERLAY luw_id;             /* Logical Unit of Work ID           */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} TP_OVERLAY;

typedef struct conv_overlay {          /* One for each active conv          */

  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the current tp_overlay + tp_overlay_len + sizeof(tp_entry_len). To find*/
  /* the next block of conversation information, add: conv_entry_len        */
  /**************************************************************************/

    ULONG  conv_entry_len;             /* Size of conversation information  */
    ULONG  conv_id;                    /* Conversation ID                   */
    UCHAR  conv_corr_len;              /* Coversation correlator length     */
    UCHAR  conv_corr[8];               /* Conversation correlator           */
    UCHAR  state;                      /* Conversation state                */
                                       /*    AP_RESET_STATE                 */
                                       /*    AP_SEND_STATE                  */
                                       /*    AP_RECEIVE_STATE               */
                                       /*    AP_CONFIRM_STATE               */
                                       /*    AP_CONFIRM_SEND_STATE          */
                                       /*    AP_CONFIRM_DEALL_STATE         */
                                       /*    AP_PEND_DEALL_STATE            */
                                       /*    AP_END_CONV_STATE              */
                                       /*    AP_TP_VALID_PEND_STATE         */
                                       /*    AP_PEND_POST_STATE             */
                                       /*    AP_SEND_RECEIVE_STATE          */
                                       /*    AP_SEND_ONLY_STATE             */
                                       /*    AP_RECEIVE_ONLY_STATE          */
    UCHAR  sess_id[8];                 /* Session ID                        */
    UCHAR  sync_level;                 /* Sync level                        */
                                       /*    AP_NONE                        */
                                       /*    AP_CONFIRM                     */
                                       /*    AP_SYNCPT                      */
    UCHAR  conv_type;                  /* Conversation type                 */
                                       /*    AP_BASIC_CONVERSATION          */
                                       /*    AP_MAPPED_CONVERSATION         */
    ULONG  conv_group_id;              /* Conversation Group ID             */
    UCHAR  conversation_source;        /* Source of conversation            */
                                       /*    AP_LOCAL_LU                    */
                                       /*    AP_PARTNER_LU                  */
    UCHAR  conversation_style;         /* Conversation style                */
                                       /*    AP_TWO_WAY_ALTERNATE           */
                                       /*    AP_TWO_WAY_SIMULTANEOUS        */
    UCHAR  source_send_byte_count[8];  /* Total bytes count sent by source  */
                                       /*   on conversation conv_id         */
    UCHAR  target_send_byte_count[8];  /* Total bytes count sent by target  */
                                       /*   on conversation conv_id         */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} CONV_OVERLAY;

typedef struct sess_info_sect {        /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: sess_info_ptr                 */
  /**************************************************************************/

    ULONG  sess_init_sect_len;         /* Structure length                  */
    USHORT num_sessions;               /* Number of Active Aessions         */
    USHORT total_sessions;             /* Total Number of Active Sessions   */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} SESS_INFO_SECT;

typedef struct sess_overlay {          /* One for each active sess          */

  /**************************************************************************/
  /* The address of the first of these structures should be: sess_info_ptr +*/
  /* sess_info_ptr->sess_init_sect_len.  To find the next block of session  */
  /* information, add: sess_entry_len                                       */
  /**************************************************************************/

    ULONG  sess_entry_len;             /* Size of session info              */
    ULONG  reserv3;                    /* Reserved                          */
    UCHAR  sess_id[8];                 /* Session ID                        */
    ULONG  conv_id;                    /* Conversation ID                   */
    UCHAR  lu_alias[8];                /* LU Alias (ASCII)                  */
    UCHAR  plu_alias[8];               /* Partner LU Alias (ASCII)          */
    UCHAR  mode_name[8];               /* Mode Name (EBCDIC type A)         */
    USHORT send_ru_size;               /* Max RU size for send              */
    USHORT rcv_ru_size;                /* Max RU size for receive           */
    UCHAR  send_pacing_size;           /* Send pacing size                  */
    UCHAR  rcv_pacing_size;            /* Receive pacing size               */
    UCHAR  link_id[12];                /* Link ID (in APPC), or             */
                                       /* First Hop Link Name (in APPN)     */
    UCHAR  daf;                        /* Outbound DAF                      */
    UCHAR  oaf;                        /* Outbound OAF                      */
    UCHAR  odai;                       /* ODAI                              */
    UCHAR  sess_type;                  /* Type of session                   */
                                       /*    AP_SSCP_PU_SESSION             */
                                       /*    AP_SSCP_LU_SESSION             */
                                       /*    AP_LU_LU_SESSION               */
    UCHAR  conn_type;                  /* Type of connection                */
                                       /*    AP_HOST_CONNECTION             */
                                       /*    AP_PEER_CONNECTION             */
                                       /*    AP_BOTH_CONNECTION             */
    UCHAR  sess_security;              /* Session Security                  */
                                       /*    AP_NO_SECURITY                 */
                                       /*    AP_BASIC_SECURITY              */
                                       /*    AP_ENHANCED_SECURITY           */
    FQPCID_OVERLAY fqpcid;             /* Fully Qualified Procedure         */
                                       /* Correlation Identifier            */
    UCHAR  cgid[4];                    /* Conversation Group ID             */
    UCHAR  fqlu_name[17];              /* Local Fully Qualifed LU Name      */
                                       /*        (EBCDIC)                   */
    UCHAR  fqplu_name[17];             /* Partner Fully Qualifed LU Name    */
                                       /*        (EBCDIC)                   */
    UCHAR  pacing_type;                /* Type of Pacing                    */
                                       /*    AP_FIXED                       */
                                       /*    AP_ADAPTIVE                    */
    UCHAR  session_level_encryption;   /* Session level encryption          */
                                       /*    AP_NONE                        */
                                       /*    AP_MANDATORY                   */
                                       /*    AP_SELECTIVE                   */
    UCHAR  pri_lu_indicator;           /* Source of bind on conversation    */
                                       /*    AP_LOCAL_LU                    */
                                       /*    AP_PARTNER_LU                  */
    UCHAR  trans_priority;             /* Transmission priority             */
                                       /*    AP_LOW     (0x00)              */
                                       /*    AP_MEDIUM  (0x01)              */
                                       /*    AP_HIGH    (0x02)              */
                                       /*    AP_NETWORK (0x03)              */
    UCHAR  pri_lu_send_fmd_piu_count[8];
                                       /* FMD PIU count sent by Pri. LU     */
    UCHAR  sec_lu_send_fmd_piu_count[8];
                                       /* FMD PIU count sent by Sec. LU     */
    UCHAR  pri_lu_send_non_fmd_piu_count[8];
                                       /* Non-FMD PIU count sent by Pri. LU */
    UCHAR  sec_lu_send_non_fmd_piu_count[8];
                                       /* Non-FMD PIU count sent by Sec. LU */
    UCHAR  pri_lu_send_byte_count[8];  /* Bytes sent on session by Pri. LU  */
    UCHAR  sec_lu_send_byte_count[8];  /* Bytes sent on session by Sec. LU  */
    UCHAR  plu_slu_compression_level;  /* Session compression level for     */
                                       /* the PLU to SLU direction          */
    UCHAR  plu_slu_compression_percent;/* Ratio of compressed data count    */
                                       /* to the uncompressed data count    */
                                       /* for the PLU to SLU direction      */
    UCHAR  slu_plu_compression_level;  /* Session compression level for     */
                                       /* the SLU to PLU direction          */
    UCHAR  slu_plu_compression_percent;/* Ratio of compressed data count    */
                                       /* to the uncompressed data count    */
                                       /* for the SLU to PLU direction      */
    ULONG  tcid;                       /* HPR transport connection ID       */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} SESS_OVERLAY;

typedef struct link_info_sect {        /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: link_info_ptr                 */
  /**************************************************************************/

    ULONG  link_init_sect_len;         /* Structure length                  */
    USHORT num_links;                  /* Number of active links            */
    USHORT total_links;                /* Total number of active links      */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LINK_INFO_SECT;


typedef struct link_overlay {          /* One for each active link          */

  /**************************************************************************/
  /* The address of the first of these structures should be: link_info_ptr +*/
  /* link_info_ptr->link_init_sect_len.  To find the next block of link     */
  /* information, add: link_entry_len                                       */
  /**************************************************************************/

    ULONG  link_entry_len;             /* Size of link info, incl link spec */
    UCHAR  link_id[12];                /* Link ID (Link Name in EBCDIC A)   */
    UCHAR  dlc_name[8];                /* DLC name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC adapter number                */
    UCHAR  dest_addr_len;              /* Length of adapter addr            */
    UCHAR  dest_addr[32];              /* Destination adapter addr          */
    UCHAR  inbound_outbound;           /* Inbound or outbound?              */
                                       /*    AP_OUTBOUND                    */
                                       /*    AP_INBOUND                     */
    UCHAR  state;                      /* Link state                        */
                                       /*    AP_CONALS_PND                  */
                                       /*    AP_XID_PND                     */
                                       /*    AP_CONTACT_PND                 */
                                       /*    AP_CONTACTED                   */
                                       /*    AP_DISC_PND                    */
                                       /*    AP_DISC_RQ                     */
    UCHAR  deact_link_flag;            /* Deactivate logical link           */
                                       /*    AP_NOT_IN_PROGRESS             */
                                       /*    AP_IN_PROGRESS                 */
    UCHAR  lim_res;                    /* limited resource                  */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    USHORT num_sessions;               /* Number of active sessions 0-65535 */
    USHORT ru_size;                    /* RU size 99-32767 (BTU Size)       */
    USHORT reserv4;                    /* Reserved                          */
    UCHAR  adj_fq_cp_name[17];         /* Adjacent Fully Qualified CP Name  */
    UCHAR  reserv5;                    /* Reserved                          */
    UCHAR  adj_node_type;              /* Adjacent Node Type                */
                                       /*    AP_EN                          */
                                       /*    AP_NN                          */
                                       /*    AP_LEN                         */
    UCHAR  cp_cp_sess_spt;             /* CP CP Session Support             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  conn_type;                  /* Type of Connection                */
                                       /*    AP_HOST_CONNECTION             */
                                       /*    AP_PEER_CONNECTION             */
                                       /*    AP_BOTH_CONNECTION             */
    UCHAR  ls_role;                    /* Link Station Role                 */
                                       /*    AP_NEGOTIABLE                  */
                                       /*    AP_PRIMARY                     */
                                       /*    AP_SECONDARY                   */
    UCHAR  line_type;                  /* Line Type                         */
                                       /*    AP_SWITCHED                    */
                                       /*    AP_NONSWITCHED                 */
    UCHAR  tg_number;                  /* Transmission Group Number         */
    ULONG  eff_capacity;               /* Effective Capacity                */
                                       /*    0 | 1200 | 2400 | ...          */
                                       /*    ... | 16M | ...                */
    UCHAR  conn_cost;                  /* Cost Per Connect Time             */
    UCHAR  byte_cost;                  /* Cost Per Byte                     */
    UCHAR  propagation_delay;          /*    AP_PROP_DELAY_MINIMUM          */
                                       /*    AP_PROP_DELAY_LAN              */
                                       /*    AP_PROP_DELAY_TELEPHONE        */
                                       /*    AP_PROP_DELAY_PKT_SWITCHED_NET */
                                       /*    AP_PROP_DELAY_SATELLITE        */
                                       /*    AP_PROP_DELAY_MAXIMUM          */
    UCHAR  user_def_1;                 /* User Defined 1                    */
    UCHAR  user_def_2;                 /* User Defined 2                    */
    UCHAR  user_def_3;                 /* User Defined 3                    */
    UCHAR  security;                   /* Security                          */
                                       /*    AP_SEC_NONSECURE               */
                                       /*    AP_SEC_PUBLIC_SWITCHED_NETWORK */
                                       /*    AP_SEC_UNDERGROUND_CABLE       */
                                       /*    AP_SEC_SECURE_CONDUIT          */
                                       /*    AP_SEC_GUARDED_CONDUIT         */
                                       /*    AP_SEC_ENCRYPTED               */
                                       /*    AP_SEC_GUARDED_RADIATION       */
    UCHAR  reserv6;                    /* Reserved                          */
    UCHAR  pu_name[8];                 /* PU Name (EBCDIC Type A)           */
    UCHAR  *subfields_start;           /* Pointer to link-related subfields */
    UCHAR  node_id_sent[4];            /* Node (XID) sent to adjacent node  */
    UCHAR  node_id_rcvd[4];            /* Node (XID) received from adj node */
    UCHAR  hpr_enabled;                /* HPR enabled on this link          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  inbound_anr_len;            /* Inbound ANR label length          */
    UCHAR  inbound_anr_label[8];       /* Inbound ANR label                 */
    UCHAR  outbound_anr_len;           /* Outbound ANR label length         */
    UCHAR  outbound_anr_label[8];      /* Outbound ANR label                */
    UCHAR  hpr_sap;                    /* HPR SAP                           */
    UCHAR  adj_node_hpr_lvl;           /* Adjacent Node HPR level           */
                                       /*    AP_NONE                        */
                                       /*    AP_ANR                         */
                                       /*    AP_RTP                         */
                                       /*    AP_CONTROL_FLOWS_OVER_RTP      */
    UCHAR  reserv7;                    /* Reserved                          */
    UCHAR  fq_primary_dlus_len;        /* Length of fq primary DLuS Name    */
    UCHAR  fq_primary_dlus_name[17];   /* Fully Qualified primary DLuS Name */
                                       /*    0 or 3-17 bytes (EBCDIC type A)*/
    UCHAR  fq_backup_dlus_len;         /* Length of fq Backup DLuS Name     */
    UCHAR  fq_backup_dlus_name[17];    /* Fully Qualified Backup DLuS Name  */
                                       /*    0 or 3-17 bytes (EBCDIC type A)*/
    UCHAR  primary_link_name[8];       /* Link Name (EBCDIC)                */
    UCHAR  reserv8[2];                 /* Reserved                          */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

    /************************************************************************/
    /* Link-related subfields may be present here.  They will be counted    */
    /* in the link_entry_len, and will be pointed to by subfields_start.    */
    /* If subfields_start is NULL, no subfields are present for this link.  */
    /*                                                                      */
    /* Not all subfields will be present for every link: Only IDLC & X.25   */
    /* have protocol-specific information and the CCITT subfields present   */
    /* will vary with the network and/or switch provider.                   */
    /*                                                                      */
    /* To access the subfields, set a pointer equal to subfields_start,     */
    /* cast to SSMGT_SUBFIELD type and examine the identification and type  */
    /* fields to determine what type of subfield it is.  If you wish to     */
    /* process the subfield, cast the pointer to the appropriate subfield   */
    /* type, chosen from the following declarations.   Note that there      */
    /* new subfields added in the future; your program should ignore any    */
    /* such subfield it does not know how to process.                       */
    /*                                                                      */
    /* To advance to the next subfield, add the subfield length to the      */
    /* SSMGT_SUBFIELD pointer and repeat the process, stopping when the     */
    /* offset of the SSMGT_SUBFIELD pointer passes the link_entry_len.      */
    /************************************************************************/

    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use link_entry_len to skip over them.                                */
    /************************************************************************/

} LINK_OVERLAY;

typedef struct ssmgt_subfield {        /* Generic SS Mgt subfield           */
   USHORT  sf_length;                  /* Subfield length (inclusive)       */
   UCHAR   sf_identifier;              /* Subfield class identifier         */
                                       /*    SF_SFID_CCITT             0x80 */
                                       /*    SF_SFID_NETWORK_SPECIFIC  0x01 */
                                       /*    SF_SFID_PROD_SPECIFIC     0x02 */
                                       /*    SF_SFID_PRM_SPECIFIC      0x04 */
                                       /*                                   */
   UCHAR   sf_type;                    /* Subfield type within class        */
                                       /*  for SF_SFID_CCITT:               */
                                       /*   SF_CC_TYPE_BEAR_CAP        0x04 */
                                       /*   SF_CC_TYPE_CHANNEL_ID      0x18 */
                                       /*   SF_CC_TYPE_CALLING_NUMBER  0x6C */
                                       /*   SF_CC_TYPE_CALLED_NUMBER   0x70 */
                                       /*   SF_CC_TYPE_CALLING_SUBADDR 0x6D */
                                       /*   SF_CC_TYPE_CALLED_SUBADDR  0x71 */
                                       /*   SF_CC_TYPE_LOW_LAYER_COMP  0x7C */
                                       /*   SF_CC_TYPE_HIGH_LAYER_COMP 0x7D */
                                       /*   SF_CC_TYPE_USER_USER_INFO  0x7E */
                                       /*   SF_CC_TYPE_DISPLAY         0x28 */
                                       /*                                   */
                                       /*  for SF_SFID_NETWORK_SPECIFIC:    */
                                       /*    SF_CC_TYPE_NS_DATE        0x03 */
                                       /*                                   */
                                       /*  for SF_SFID_PRM_SPECIFIC:        */
                                       /*                                   */
                                       /*    SF_CC_TYPE_CALL_INFO      0x01 */
                                       /*                                   */
                                       /*  for SF_SFID_PRD_SPECIFIC:        */
                                       /*                                   */
                                       /*    SF_PS_TYPE_PROT_SPECIFIC 0x01  */

    /************************************************************************/
    /* Additional subfield-dependent fields are located in this position.   */
    /* See the individual subfield declarations for details, or use the     */
    /* subfield length to skip over them.                                   */
    /************************************************************************/

} SSMGT_SUBFIELD;

typedef struct prot_spec_sf    {       /* Protocol-specific parameters      */
    USHORT length;                     /* SF length - varies                */
    UCHAR  identifier;                 /* SF identifier                     */
                                       /*   SF_SFID_PRD_SPECIFIC       0x02 */
    UCHAR  type;                       /* SF type                           */
                                       /*   SF_PS_TYPE_PROT_SPECIFIC   0x01 */
    UCHAR  protocol_id;                /* Connection Mgr protocol id        */
                                       /*   CMI_CM_PROT_ID_X_25        0x03 */
                                       /*   CMI_CM_PROT_ID_IDLC        0x05 */
    UCHAR  prot_spec_sf_data[1];       /* varies by protocol id             */

} PROT_SPEC_SF;

typedef struct idlc_prot_spec_sf {     /* IDLC protocol-specific subfield   */
    USHORT length;                     /* SF length                     15  */
    UCHAR  identifier;                 /* SF identifier                     */
                                       /*   SF_SFID_PRD_SPECIFIC       0x02 */
    UCHAR  type;                       /* SF type                           */
                                       /*   SF_PS_TYPE_PROT_SPECIFIC   0x01 */
    UCHAR  prot_id;                    /* protocol id                       */
                                       /*   CMI_CM_PROT_ID_IDLC        0x05 */
    UCHAR  reserv1;                    /* Reserved                          */
    USHORT idlc_T200;                  /* retransmission timer              */
    USHORT idlc_T203;                  /* inactivity timer                  */
    USHORT idlc_N201;                  /* maximum I-frame size              */
    UCHAR  idlc_N200;                  /* retransmission counter            */
    UCHAR  idlc_k;                     /* max number unacknowledged I-frames*/
    UCHAR  idlc_Nw;                    /* dynamic window step size          */

    /************************************************************************/
    /*       Additional fields may be added here in future releases.        */
    /************************************************************************/

} IDLC_PROT_SPEC_SF;

typedef struct sdlc_prot_spec_sf {     /* SDLC protocol-specific subfield   */
    USHORT length;                     /* SF length                      8  */
    UCHAR  identifier;                 /* SF identifier                     */
                                       /*   SF_SFID_PRD_SPECIFIC       0x02 */
    UCHAR  type;                       /* SF type                           */
                                       /*   SF_PS_TYPE_PROT_SPECIFIC   0x01 */
    UCHAR  prot_id;                    /* protocol id                       */
                                       /*   CMI_CM_PROT_ID_SDLC =      0x04 */
    UCHAR  sdlc_T200;                  /* retransmission timer              */
    UCHAR  sdlc_T203;                  /* inactivity timer                  */
    UCHAR  sdlc_retry_count;           /* retry count                       */

    /************************************************************************/
    /*       Additional fields may be added here in future releases.        */
    /************************************************************************/

} SDLC_PROT_SPEC_SF;

typedef struct x25_prot_spec_sf {      /* X.25 protocol-specific subfield   */
    USHORT length;                     /* SF length                     22  */
    UCHAR  identifier;                 /* SF identifier                     */
                                       /*   SF_SFID_PRD_SPECIFIC       0x02 */
    UCHAR  type;                       /* SF type                           */
                                       /*   SF_PS_TYPE_PROT_SPECIFIC   0x01 */
    UCHAR  prot_id;                    /* Protocol identifier               */
                                       /*   CMI_CM_PROT_ID_X_25        0x03 */
    UCHAR  reserv1;                    /* Reserved                          */
    UCHAR  destination_name[8];        /* Destination directory name        */
    UCHAR  destination_type;           /* CCITT protocol compatibility      */
                                       /*   0x00 = CCITT 1980 version       */
                                       /*   0x01 = CCITT 1984 version       */
    UCHAR  req_rev_charge;             /* Outgoing calls will be collect    */
                                       /*   AP_NO                           */
                                       /*   AP_YES                          */
    UCHAR  accept_rev_charge;          /* Accept incoming collect calls     */
                                       /*   AP_NO                           */
                                       /*   AP_YES                          */
    UCHAR  x25_protocol_version;       /* SNA protocol version used         */
                                       /*   0x00 = QLLC                     */
    USHORT retry_count;                /* Max number of timeout retries     */
    USHORT timeout;                    /* Time between retries              */
    USHORT incoming_packet_size;       /* Packet size expected              */
    UCHAR  retry_call_collision;       /* Retry flag if call collision      */
                                       /*   AP_NO                           */
                                       /*   AP_YES                          */

    /************************************************************************/
    /*       Additional fields may be added here in future releases.        */
    /************************************************************************/

} X25_PROT_SPEC_SF;

typedef struct cmgr_ci_subfield {      /* Conn. Mgr. Call Instance subfield */
    USHORT length;                     /* subfield length                   */
    UCHAR  identifier;                 /*   SF_SFID_PRM_SPECIFIC            */
    UCHAR  type;                       /*   SF_CC_TYPE_CALL_INFO            */
    UCHAR  entryname[16];              /* OCDT Entry Name or blank          */
    UCHAR  call_state;                 /* switched call state               */
                                       /*    CS_NULL_CALL              0x00 */
                                       /*    CS_OUT_CALL_ORIG          0x01 */
                                       /*    CS_OVERLAP_SEND           0x02 */
                                       /*    CS_OUT_CALL_PROC          0x03 */
                                       /*    CS_OUT_CALL_DELIVERED     0x04 */
                                       /*    CS_OUT_CALL_CONN_PEND     0x05 */
                                       /*    CS_IN_CALL_PRESENT        0x06 */
                                       /*    CS_IN_CALL_RECV           0x07 */
                                       /*    CS_IN_CALL_CONN_PEND      0x08 */
                                       /*    CS_IN_CALL_PROC           0x09 */
                                       /*    CS_ACTIVE_CALL            0x0A */
                                       /*    CS_DISC_REQUEST           0x0B */
                                       /*    CS_DISC_INDICATION        0x0C */
    UCHAR  call_direction;             /* switched call type                */
                                       /*    CS_TYPE_INCOMING          0x00 */
                                       /*    CS_TYPE_OUTGOING          0x01 */
    UCHAR  pcm_name[16];               /* name of PCM controlling this call */
    UCHAR  adapter_num;                /* logical adapter number            */
    UCHAR  protocol_id;                /* protocol in use on B channel      */
                                       /*    PROT_ID_UNSPECIFIED       0x00 */
                                       /*    PROT_ID_802_2             0x01 */
                                       /*    PROT_ID_NETBIOS           0x02 */
                                       /*    PROT_ID_X_25              0x03 */
                                       /*    PROT_ID_SDLC              0x04 */
                                       /*    PROT_ID_IDLC              0x05 */

    /************************************************************************/
    /*       Additional fields may be added here in future releases.        */
    /************************************************************************/

} CMGR_CI_SUBFIELD;


/****************************************************************************/
/*                                                                          */
/*      Overlays for the Call Control subfields are located in SF.H         */
/*                                                                          */
/****************************************************************************/


typedef struct icas_info_sect {        /* Incoming Call Auto-answer Status  */

  /**************************************************************************/
  /* The address of this structure should be: icas_info_ptr                 */
  /**************************************************************************/

   ULONG  init_sect_len;               /* Length of this header             */
   USHORT num_icas_entries;            /* Number of entries following       */
   USHORT tot_icas_entries;            /* Total number of entries defined   */

   /*************************************************************************/
   /* Additional fields may be added here in future releases                */
   /*************************************************************************/

} ICAS_INFO_SECT;

typedef struct icas_entry {            /* One entry for each class of call  */
                                       /* which may be automatically        */
                                       /* answered                          */

   /*************************************************************************/
   /* The address of the first of these structures should be:               */
   /*   icas_info_ptr + icas_info_ptr->init_sect_len                        */
   /* To find the next entry, add: icas_entry_ptr->entry_len.               */
   /*************************************************************************/

   ULONG  entry_len;                   /* Length of this entry              */
   UCHAR  icrt_entry_name[16];         /* Incoming Call Routing Table entry */
   UCHAR  icrt_entry_accept_call;      /* ICRT entry accept status          */
   UCHAR  rsrvd1;                      /* Reserved                          */

   /*************************************************************************/
   /* Additional fields may be added here in future releases                */
   /*************************************************************************/

} ICAS_ENTRY;

typedef struct lu_0_3_info_sect {      /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: lu_0_3_info_ptr               */
  /**************************************************************************/

    ULONG  lu_0_3_init_sect_len;       /* Structure length                  */
    USHORT num_lu_0_3s;                /* Number of configured LUs          */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LU_0_3_INFO_SECT;

typedef struct lu_0_3_overlay {        /* One for each configured LU        */

  /**************************************************************************/
  /* The address of the first of these structures should be: lu_0_3_info_ptr*/
  /* + lu_0_3_info_ptr->lu_0_3_init_sect_len.  To find the next one, add:   */
  /* lu_0_3_entry_len.                                                      */
  /**************************************************************************/

    ULONG  lu_0_3_entry_len;           /* Size of this LU info              */
    UCHAR  access_type;                /* Access type                       */
                                       /*    AP_3270_EMULATION              */
                                       /*    AP_LUA                         */
    UCHAR  lu_type;                    /* LU type                           */
                                       /*    AP_LU0                         */
                                       /*    AP_LU1                         */
                                       /*    AP_LU2                         */
                                       /*    AP_LU3                         */
    UCHAR  lu_daf;                     /* NAU address                       */
    UCHAR  lu_short_name;              /* LU Short Name (ASCII)             */
    UCHAR  lu_long_name[8];            /* LU Long Name (ASCII)              */
    UCHAR  sess_id[8];                 /* Session ID                        */
    UCHAR  dlc_name[8];                /* DLC Name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC Adapter number                */
    UCHAR  dest_addr_len;              /* Length of Adapter Addr            */
    UCHAR  dest_addr[32];              /* Destination Adapter Addr          */
    UCHAR  sscp_lu_sess_state;         /* SSCP-LU Session State             */
                                       /*    AP_DEACTIVATED                 */
                                       /*    AP_ACTIVATED                   */
                                       /*    AP_ACTIVATING                  */
                                       /*    AP_DEACTIVATING                */
                                       /*    any of these 4 states can be   */
                                       /*    &'ed with: AP_DETACHING        */
    UCHAR  lu_lu_sess_state;           /* LU-LU Session State               */
                                       /*    AP_NOT_BOUND                   */
                                       /*    AP_BOUND                       */
                                       /*    AP_BINDING                     */
                                       /*    AP_UNBINDING                   */
    UCHAR  link_id[12];                /* Link Name (EBCDIC Type A)         */
    UCHAR  pu_name[8];                 /* PU Name for Multiple PU           */
    UCHAR  partnerlu[17];              /* Partner_LU_Name                   */
    UCHAR  plu_slu_compression_level;  /* compression level for the plu to  */
                                       /* slu direction                     */
    UCHAR  slu_plu_compression_level;  /* compression level for the slu to  */
                                       /* plu direction                     */
    UCHAR  fq_host_known_luname[17];   /* LU name as known at the host      */
    UCHAR  lu_model_name[7];           /* LU model name                     */
    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LU_0_3_OVERLAY;

typedef struct gw_info_sect {          /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: gw_info_ptr                   */
  /**************************************************************************/

    ULONG  gw_init_sect_len;           /* Structure length                  */
    USHORT num_gw_lus;                 /* Number of configured              */

    /************************************************************************/
    /* gateway LUs Additional fields may be added here in future releases   */
    /************************************************************************/

} GW_INFO_SECT;

typedef struct gw_overlay {            /* One for each gateway LU           */

  /**************************************************************************/
  /* The address of the first of these structures should be: gw_info_ptr +  */
  /* gw_info_ptr->gw_init_sect_len. To find the next one, add: gw_entry_len.*/
  /**************************************************************************/

    ULONG  gw_entry_len;               /* Size of the gateway info          */
    UCHAR  ws_lu_name[8];              /* WS LU name (EBCDIC)               */
    UCHAR  ws_pool_name[8];            /* WS pool class name                */
    SHORT  ws_logoff_time_left;        /* WS LU time before logoff          */
    UCHAR  ws_local_addr;              /* Workstation local address         */
    UCHAR  host_local_addr;            /* Host local address                */
    UCHAR  ws_lu_type;                 /* Workstation LU type               */
                                       /*    AP_LU0                         */
                                       /*    AP_LU1                         */
                                       /*    AP_LU2                         */
                                       /*    AP_LU3                         */
                                       /*    AP_LU62                        */
                                       /*    AP_UNKNOWN                     */
    UCHAR  host_lu_name[17];           /* Host LU name (EBCDIC)             */
    UCHAR  ws_dlc_name[8];             /* WS DLC name (ASCII)               */
    UCHAR  ws_adapter_num;             /* Workstation adapter num           */
    UCHAR  ws_dest_addr_len;           /* WS dest addr length               */
    UCHAR  ws_dest_addr[16];           /* WS destination addr               */
    UCHAR  host_link_name[8];          /* APPN name for host link           */
    UCHAR  ws_link_name[8];            /* APPN name for workstation link    */
    UINT   ws_link_act:1;              /* Bit  15 WS link active?           */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_lu_pend_term:1;          /* Bit 14 LU-LU pending termination? */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_lu_pend_init:1;          /* Bit 13  LU-LU pending initiation? */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_lu_act:1;                /* Bit 12  LU-LU Active?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_cp_pend_term:1;          /* Bit 11 LU-CP Pending Termination? */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_cp_pend_init:1;          /* Bit 10  LU-CP pending initiation? */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_cp_act_offline:1;        /* Bit 9  LU-CP active offline?      */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   lu_cp_act_online:1;         /* Bit 8  LU-CP active online?       */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   ws_dedicated_link:1;        /* Bit 7 Is WS on dedicated Link?    */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   ws_passthru:1;              /* Bit 6 WS alerts passed thru       */
                                       /*       to host Focal Point?        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UINT   reserv4:6;                  /* Bits 0-7  Reserved                */
    UCHAR  lu_model_name[7];           /* LU model name                     */
    UCHAR  ws_cp_name[17];             /* Workstation CP name (EBCDIC)      */
    /************************************************************************/
    /* Reserved Additional fields may be added here in future releases      */
    /************************************************************************/

} GW_OVERLAY;

typedef struct x25_physical_link_info_sect { /* One of these              */

  /**************************************************************************/
  /* The address of this structure should be: x25_physical_link_info_ptr    */
  /**************************************************************************/

    ULONG  x25_init_sect_len;          /* Structure length                  */
    USHORT num_x25_links;              /* Number of X.25 physical links     */
    USHORT num_x25_link_entries;       /* Total Number of X.25 phys. links  */

    /************************************************************************/
    /* physical link entries Additional fields may be added here in future  */
    /* releases                                                             */
    /************************************************************************/

} X25_PHYSICAL_LINK_INFO_SECT;

typedef struct x25_overlay {           /* One for each X.25 link            */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* x25_physical_link_info_ptr + x25_physical_link_ptr->x25_init_sect_len  */
  /* To find the next one, add: x25_entry_len                               */
  /**************************************************************************/

    ULONG  x25_entry_len;              /* Size of X.25 information          */
    UCHAR  link_name[8];               /* X.25 Link Name (ASCII)            */
    UCHAR  link_comments[60];          /* Comment Field (ASCII)             */
    USHORT adapter_slot_num;           /* Adapter Slot Number               */
    UCHAR  link_type;                  /* Link Type                         */
                                       /*    AP_LEASED_LINE                 */
                                       /*    AP_VX32                        */
    UCHAR  link_mode;                  /* Link Mode                         */
                                       /*    AP_DISCONNECT                  */
                                       /*    AP_CONNECT                     */
                                       /*    AP_AUTO_CONNECT                */
    UCHAR  link_state;                 /* Link State                        */
                                       /*    AP_CONNECTING                  */
                                       /*    AP_CONNECTED                   */
                                       /*    AP_ERROR_LEVEL_1               */
                                       /*    AP_ERROR_LEVEL_2               */
                                       /*    AP_DISCONNECTING               */
                                       /*    AP_DISCONNECTED                */
                                       /*    AP_ADAPTER_ERROR               */
                                       /*    AP_ADAPTER_ACCESS_ERROR        */
                                       /*    AP_INCOMING_WAIT               */
    UCHAR  link_direction;             /* Link Direction                    */
                                       /*    AP_INCOMING                    */
                                       /*    AP_OUTGOING                    */
                                       /*    AP_2_WAY                       */
    USHORT num_act_pvcs;               /* Number of Active PVCs             */
    USHORT total_num_pvcs;             /* Total Number of PVCs              */
    USHORT num_act_svcs;               /* Number of Active SVCs             */
    USHORT num_incoming_svcs;          /* Num of Incoming SVCs              */
    USHORT num_2_way_svcs;             /* Number of 2-way SVCs              */
    USHORT num_outgoing_svcs;          /* Num of Outgoing SVCs              */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} X25_OVERLAY;

typedef struct sys_def_info_sect {     /*                                   */

  /**************************************************************************/
  /* The address of this structure should be: sys_def_info_ptr              */
  /**************************************************************************/

    UCHAR  default_mode_name[8];       /* Default Mode Name (EBCDIC type A) */
    UCHAR  default_local_lu_name[8];   /* Default Local LU Name (EBCDIC     */
                                       /*    type A)                        */
    UCHAR  implicit_inb_rlu_supp;      /* Implicit Remote LU Support        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  max_held_alerts;            /* Max Held Alerts 0-255             */
    UCHAR  tp_conv_sec_rqd;            /* TP Conversation Security Requested*/
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv3;                    /* Reserved                          */
    USHORT max_mc_ll_send_size;        /* Maximum Mapped Conversation       */
                                       /* Logical Record Send Size          */
                                       /*    0 or 2048 - 32767              */
    UCHAR  dir_for_attaches[64];       /* Directory For Inbound Attaches    */
    UCHAR  tp_operation;               /* Default TP Operation              */
                                       /*    AP_QUEUED_OPERATOR_STARTED     */
                                       /*    AP_QUEUED_AM_STARTED           */
                                       /*    AP_NONQUEUED_AM_STARTED        */
                                       /*    AP_QUEUED_OPERATOR_PRELOADED   */
    UCHAR  tp_program_type;            /* Default TP Program Type           */
                                       /*    AP_BACKGROUND                  */
                                       /*    AP_FULL_SCREEN                 */
                                       /*    AP_PRESENTATION_MANAGER        */
                                       /*    AP_VIO_WINDOWABLE              */
    UCHAR  implicit_link_hpr_supp;     /* Implicit Link HPR Support         */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  retry_count;                /* Retry Count, 0-255                */
    USHORT alive_timer;                /* Alive Timer, 0-65535              */
    USHORT path_switch_timer_low;      /* Path Switch Timer (low), 0-65535  */
    USHORT path_switch_timer_medium;   /* Path Switch Timer (med), 0-65535  */
    USHORT path_switch_timer_high;     /* Path Switch Timer (high), 0-65535 */
    UCHAR  default_routing_preference; /* Default routing preference        */
                                       /*    AP_NATIVE_FIRST                */
                                       /*    AP_NON_NATIVE_FIRST            */
                                       /*    AP_NATIVE_ONLY                 */
                                       /*    AP_NON_NATIVE_ONLY             */
    UCHAR  TN3270_fields[9];           /* Room for TN3270 fields            */
    UCHAR  disable_dlur_reg;           /* Disable DLUR Registration?        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} SYS_DEF_INFO_SECT;

typedef struct adapter_info_sect {     /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: adapter_info_ptr              */
  /**************************************************************************/

    ULONG  adapter_init_sect_len;      /* Structure length                  */
    USHORT num_adapters;               /* Number of Adapters Displayed      */
    USHORT total_adapters;             /* Total Number of Adapters          */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} ADAPTER_INFO_SECT;

typedef struct adapter_overlay {       /* One for each adapter Displayed    */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* adapter_info_ptr + adapter_info_ptr->adapter_init_sect_len.            */
  /* To find the next one, add: adapter_entry_len                           */
  /**************************************************************************/

    ULONG  adapter_entry_len;          /* Size of Adapter Info              */
    UCHAR  dlc_name[8];                /* DLC Name (ASCII)                  */
    UCHAR  adapter_number;             /* Adapter Number                    */
                                       /*    0-255                          */
    UCHAR  ls_role;                    /* Link Station Role                 */
                                       /*    AP_NEGOTIABLE                  */
                                       /*    AP_PRIMARY                     */
                                       /*    AP_SECONDARY                   */
    UCHAR  reserv2[4];                 /* Reserved                          */
    UCHAR  conn_cost;                  /* Cost Per Connect Time             */
    UCHAR  byte_cost;                  /* Cost Per Byte                     */
    UCHAR  propagation_delay;          /*    AP_PROP_DELAY_MINIMUM          */
                                       /*    AP_PROP_DELAY_LAN              */
                                       /*    AP_PROP_DELAY_TELEPHONE        */
                                       /*    AP_PROP_DELAY_PKT_SWITCHED_NET */
                                       /*    AP_PROP_DELAY_SATELLITE        */
                                       /*    AP_PROP_DELAY_MAXIMUM          */
    UCHAR  user_def_1;                 /* User Defined 1                    */
    UCHAR  user_def_2;                 /* User Defined 2                    */
    UCHAR  user_def_3;                 /* User Defined 3                    */
    UCHAR  security;                   /* Security                          */
                                       /*    AP_SEC_NONSECURE               */
                                       /*    AP_SEC_PUBLIC_SWITCHED_NETWORK */
                                       /*    AP_SEC_UNDERGROUND_CABLE       */
                                       /*    AP_SEC_SECURE_CONDUIT          */
                                       /*    AP_SEC_GUARDED_CONDUIT         */
                                       /*    AP_SEC_ENCRYPTED               */
                                       /*    AP_SEC_GUARDED_RADIATION       */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  line_type;                  /* Line Yype                         */
                                       /*    AP_SWITCHED                    */
                                       /*    AP_NONSWITCHED                 */
    UCHAR  lim_res;                    /* Limited Resource ?                */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    USHORT lim_res_timeout;            /* Limited Resource Timeout          */
                                       /*    0-127 ???                      */
    USHORT max_btu_size;               /* Maximum BTU Size 99-32767         */
    UCHAR  rcv_window;                 /* Receive Window 0-127              */
    UCHAR  send_window;                /* Send Window 0-127                 */
    USHORT max_ls_used;                /* Max Link Stations                 */
    UCHAR  abm_support;                /* Asynchronous Balanced Mode Used?  */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  adapter_active;             /* Adapter Active?                   */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  adapter_type;               /* Adapter Type                      */
                                       /*    AP_NON_DIALED                  */
                                       /*    AP_DYNAMIC_SWITCHED            */
                                       /*    AP_GDLC                        */
    UCHAR  max_link_act_attempts;      /* Adapter link retry count          */
                                       /*    AP_NO_ACT_LIMIT or 1-99        */
    ULONG  eff_capacity;               /* Effective Capacity                */
                                       /*    1200 | 2400 |...|16M|...       */
    UCHAR  discovery_enabled;          /* Discovery Enabled?                */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  discovery_active;           /* Discovery Active?                 */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    USHORT group_name_count;           /* Group Name Count 0-16             */
    ULONG  discovery_node_type;        /* Node Type                         */
                                       /*    AP_GATEWAY_SERVER              */
                                       /*    AP_NN_SERVER                   */
    UCHAR  group_name_array[16][8];    /* Group Name Array                  */

} ADAPTER_OVERLAY;


typedef struct lu_def_info_sect {      /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: lu_def_info_ptr               */
  /**************************************************************************/

    ULONG  lu_def_init_sect_len;       /* Structure length                  */
    USHORT num_lu_def;                 /* Number of LU Definitions Displayed*/
    USHORT total_lu_def;               /* Total Number of LU Definitions    */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LU_DEF_INFO_SECT;

typedef struct lu_def_overlay {        /* One for each lu_def Displayed     */

  /**************************************************************************/
  /* The address of the first of these structures should be: lu_def_info_ptr*/
  /* + lu_def_info_ptr->lu_def_init_sect_len.  To find the next one, add:   */
  /* lu_def_entry_len                                                       */
  /**************************************************************************/

    ULONG  lu_def_entry_len;           /* Size of lu def info               */
    UCHAR  lu_name[8];                 /* LU_NAME (EBCDIC type A)           */
    UCHAR  lu_alias[8];                /* LU_ALIAS (ASCII)                  */
    UCHAR  lu_nau_addr;                /* NAU address 0-254                 */
    UCHAR  lu_type;                    /* Workstation LU type               */
    UCHAR  pu_name[8];                 /* PU Name (EBCDIC Type A)           */
    UCHAR  lu_model_name[7];           /* LU model name                     */
    UCHAR  reserv4;                    /* Reserved                          */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LU_DEF_OVERLAY;

typedef struct plu_def_info_sect {     /*   One of these                    */

  /**************************************************************************/
  /* The address of this structure should be: plu_def_info_ptr              */
  /**************************************************************************/

    ULONG  plu_def_init_sect_len;      /* Struct length                     */
    USHORT num_plu_def;                /* Number of Partner LU defs Displayd*/
    USHORT total_plu_def;              /* Total Number of Partner LU defs   */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} PLU_DEF_INFO_SECT;

typedef struct plu_def_overlay {       /* One for each plu_def displayed    */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* plu_def_info_ptr + plu_def_info_ptr->plu_def_init_sect_len.  To find   */
  /* the next one, add: plu_def_entry_len.                                  */
  /**************************************************************************/

    ULONG  plu_def_entry_len;          /* Size of plu def info              */
    UCHAR  fqplu_name[17];             /* PLU Name (EBCDIC)                 */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  plu_alias[8];               /* Partner LU Alias                  */
    UCHAR  plu_uninterpreted_name[8];  /* Partner LU Uninterpreted Name     */
                                       /*           (EBCDIC)                */
    USHORT max_mc_ll_ssize;            /* Maximum Mapped Conversation       */
                                       /* Logical Record Send Size          */
                                       /*    0 or 2048 - 32767              */
    UCHAR  conv_security;              /* Conversation Security             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  parallel_sess;              /* Parallel Session Support          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  default_routing_preference; /* Default Routing Preference        */
                                       /*    AP_NATIVE_FIRST                */
                                       /*    AP_NON_NATIVE_FIRST            */
                                       /*    AP_NATIVE_ONLY                 */
                                       /*    AP_NON_NATIVE_ONLY             */
    UCHAR  num_of_alt_aliases;         /* Number of alternate PLU aliases   */
                                       /* (not including the plu_alias).    */
                                       /*    0 or # of alt_alias_overlays   */
    /************************************************************************/
    /* The address of the first alternate partner LU alias is:              */
    /* plu_def_overlay + sizeof(struct plu_def_overlay).  To build the addr */
    /* of the next partner LU alias, add: sizeof(struct alt_alias_overlay). */
    /* See struct alt_alias_overlay in APPCDEF.H.                           */
    /************************************************************************/

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} PLU_DEF_OVERLAY;

typedef struct mode_def_info_sect {    /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: mode_def_info_ptr             */
  /**************************************************************************/

    ULONG  mode_def_init_sect_len;     /* Struct length                     */
    USHORT num_mode_def;               /* Number of Mode Definitions Dsplyd */
    USHORT total_mode_def;             /* Total Number of Mode Definitions  */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} MODE_DEF_INFO_SECT;

typedef struct mode_def_overlay {      /* One for each mode_def Displayed   */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* mode_def_info_ptr + mode_def_info_ptr->mode_def_init_sect_len.  To find*/
  /* the next one, add: mode_def_entry_len                                  */
  /**************************************************************************/

    ULONG  mode_def_entry_len;         /* Size of mode def info             */
    UCHAR  cos_name[8];                /* COS Name (EBCDIC)                 */
    UCHAR  mode_name[8];               /* Mode Name (EBCDIC)                */
    UCHAR  compression_need;           /* Whether compression is            */
                                       /* REQUESTED, determined by the      */
                                       /* SYSTEM from the effective         */
                                       /* capacity of the links, or         */
                                       /* PROHIBITED                        */
    UCHAR  pacing_type;                /* Pacing Type                       */
                                       /*    AP_ADAPTIVE_PACING             */
                                       /*    AP_FIXED_PACING                */
    USHORT rusize_upper;               /* max RU size upper bound           */
                                       /*    256-65535                      */
    UCHAR  rcv_window;                 /* receive pacing window             */
                                       /*    0 or 1-63                      */
    UCHAR  default_ru_size;            /* default ru size?                  */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    USHORT  max_neg_sess_lim;          /* Max limit on sessions             */
    USHORT  curr_sess_lim;             /* Current session limit             */
    USHORT  min_win_lim;               /* Min negotiated winners            */
    UCHAR  plu_slu_compression_level ; /* The level of compression to       */
                                       /* be used for the PLU to SLU        */
                                       /* direction.                        */
                                       /* 0 = NO compression = AP_NONE      */
                                       /* 1 = RLE compression               */
                                       /* 2 = LZ9 compression               */
    UCHAR  slu_plu_compression_level ; /* The level of compression to       */
                                       /* be used for the SLU to PLU        */
                                       /* direction.                        */
                                       /* 0 = NO compression = AP_NONE      */
                                       /* 1 = RLE compression               */
                                       /* 2 = LZ9 compression               */
    UCHAR  session_level_encryption;   /* Session level encryption          */
                                       /*    AP_NONE                        */
                                       /*    AP_MANDATORY                   */
                                       /*    AP_SELECTIVE                   */
                                       /*    AP_OPTIONAL                    */
    UCHAR  appn_encryption_support;    /* Appn Encrption support            */
                                       /*    AP_NONE                        */
                                       /*    AP_EN_SLE                      */
                                       /*    AP_NNS_SLE                     */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} MODE_DEF_OVERLAY;

typedef struct link_def_info_sect {    /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: link_def_info_ptr             */
  /**************************************************************************/

    ULONG  link_def_init_sect_len;     /* Structure length                  */
    USHORT num_link_def;               /* Number of Active Links Displayed  */
    USHORT total_link_def;             /* Total Number of Active Links      */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} LINK_DEF_INFO_SECT;

typedef struct link_def_overlay {      /* One for each active link Displayed*/

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* link_def_info_ptr + link_def_info_ptr->link_def_init_sect_len. To find */
  /* the next block of link information, add: link_def_entry_len            */
  /**************************************************************************/

    ULONG  link_def_entry_len;         /* Size of link info,                */
                                       /* including link specific           */
    UCHAR  link_name[8];               /* Link Name (EBCDIC)                */
    UCHAR  adj_fq_cp_name[17];         /* Adjacent Fully Qualified CP Name  */
                                       /*           (EBCDIC)                */
    UCHAR  adj_node_type;              /* adjacent node type                */
                                       /*    AP_LEARN                       */
                                       /*    AP_LEN                         */
                                       /*    AP_ADJACENT_NN                 */
    UCHAR  dlc_name[8];                /* DLC name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC adapter number                */
    UCHAR  dest_addr_len;              /* Length of adapter addr            */
    UCHAR  dest_addr[32];              /* Destination adapter addr          */
    UCHAR  cp_cp_sess_spt;             /* CP CP session support?            */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  preferred_nn_server;        /* Is this the Pref. NN Server?      */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  auto_act_link;              /* Auto Activate Link?               */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  tg_number;                  /* Transmission Group Number         */
    UCHAR  lim_res;                    /* Limited Resource ?                */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
                                       /*    AP_USE_ADAPTER_DEF_CHAR        */
    UCHAR  solicit_sscp_session;       /* Solicit SSCP Session?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  initself;                   /* Initself Indicator                */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  bind_support;               /* Bind Support?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  ls_role;                    /* link station role                 */
                                       /*    AP_NEGOTIABLE                  */
                                       /*    AP_PRIMARY                     */
                                       /*    AP_SECONDARY                   */
    UCHAR  line_type;                  /* Line Type                         */
                                       /*    AP_SWITCHED                    */
                                       /*    AP_NONSWITCHED                 */
    UCHAR  reserv1[4];                 /* Reserved                          */
    UCHAR  conn_cost;                  /* Cost Per Connect Time             */
    UCHAR  byte_cost;                  /* Cost Per Byte                     */
    UCHAR  propagation_delay;          /*    AP_PROP_DELAY_MINIMUM          */
                                       /*    AP_PROP_DELAY_LAN              */
                                       /*    AP_PROP_DELAY_TELEPHONE        */
                                       /*    AP_PROP_DELAY_PKT_SWITCHED_NET */
                                       /*    AP_PROP_DELAY_SATELLITE        */
                                       /*    AP_PROP_DELAY_MAXIMUM          */
    UCHAR  user_def_1;                 /* User Defined 1                    */
    UCHAR  user_def_2;                 /* User Defined 2                    */
    UCHAR  user_def_3;                 /* User Defined 3                    */
    UCHAR  security;                   /* Security                          */
                                       /*    AP_SEC_NONSECURE               */
                                       /*    AP_SEC_PUBLIC_SWITCHED_NETWORK */
                                       /*    AP_SEC_UNDERGROUND_CABLE       */
                                       /*    AP_SEC_SECURE_CONDUIT          */
                                       /*    AP_SEC_GUARDED_CONDUIT         */
                                       /*    AP_SEC_ENCRYPTED               */
                                       /*    AP_SEC_GUARDED_RADIATION       */
    UCHAR  max_act_attempts;           /* Maximum activation attempts       */
                                       /*    AP_NO_ACT_LIMIT or 1-255       */
    UCHAR  pu_name[8];                 /* PU Name (EBCDIC Type A)           */
    UCHAR  ocde_name[16];              /* Outgoing call directory entry name*/
    USHORT inact_timeout;              /* Inactivity timout, 0 = none       */
    UCHAR  nodeid_recv[4];             /* Adjacent node id                  */
    UCHAR  nodeid_sent[4];             /* Nodeid sent                       */
    UCHAR  use_cp_as_pu;               /* Use cp name as pu name for link?  */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  perm_conn;                  /* Permanent connection?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  hpr_support;                /* HPR support for this link?        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  backup_host_link;           /* Backup for solicit SSCP-PU        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    ULONG  eff_capacity;               /* Effective Capacity                */
                                       /*    0 | 1200 | 2400 | ...          */
                                       /*    ... | 16M | ...                */
    UCHAR  fq_primary_dlus_len;        /* Length of fq primary DLuS Name    */
    UCHAR  fq_primary_dlus_name[17];   /* Fully Qualified primary DLuS Name */
                                       /*    0 or 3-17 bytes (EBCDIC type A)*/
    UCHAR  fq_backup_dlus_len;         /* Length of fq Backup DLuS Name     */
    UCHAR  fq_backup_dlus_name[17];    /* Fully Qualified Backup DLuS Name  */
                                       /*    0 or 3-17 bytes (EBCDIC type A)*/
    UCHAR  primary_link_name[8];       /* Link Name (EBCDIC)                */

    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use link_entry_len to skip over them.                                */
    /************************************************************************/

} LINK_DEF_OVERLAY;

typedef struct ms_info_sect  {         /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: ms_info_ptr                   */
  /**************************************************************************/

    ULONG  ms_init_sect_len;           /* Structure length                  */
    UCHAR  held_mds_mu_alerts;         /* Held mds alerts                   */
                                       /*    1-255                          */
    UCHAR  held_nmvt_alerts;           /* NO LONGER USED, ALWAYS 0          */
    USHORT num_fps;                    /* Number of Focal Points Displayed  */
    USHORT total_fps;                  /* Total Number of Focal Points      */
    USHORT num_ms_appls;               /* Num. of MS Applications Displayed */
    USHORT total_ms_appls;             /* Total Number of MS Applications   */
    USHORT num_act_trans;              /* # of Active Transactions Displayed*/
    USHORT total_act_trans;            /* Total Num. of Active Transactions */
    USHORT num_local_fps;              /* # of Local FPs disp.              */
    USHORT total_local_fps;            /* Total Num. of Local FPs           */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} MS_INFO_SECT;

typedef struct ms_fp_overlay {         /* One each MS Focal Point Displayed */

  /**************************************************************************/
  /* The address of the first of these structures should be: ms_info_ptr +  */
  /* ms_info_ptr->ms_init_sect_len.  To find the next the next one, add:    */
  /* ms_fp_entry_len.                                                       */
  /**************************************************************************/

    ULONG  ms_fp_entry_len;            /* Size of MS Focal point info       */
    UCHAR  ms_appl_name[8];            /* MS Application name               */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  ms_category[8];             /* MS Category                       */
                                       /* 0 or 4 byte SNA Defined Category  */
    UCHAR  fp_fq_cp_name[17];          /* Focal Point Fully Qual. CP Name   */
                                       /*    (EBCDIC type A)                */
    UCHAR  bkup_appl_name[8];          /* Backup MS Application Name        */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  bkup_fp_fq_cp_name[17];     /* Backup Focal Point Name           */
                                       /*    (EBCDIC type A)                */
    UCHAR  retry_resp;                 /* Retry Responsibility              */
                                       /*    AP_FP_RETRY                    */
                                       /*    AP_EP_RETRY                    */
    UCHAR  fp_type;                    /* focal point rank                  */
                                       /*    AP_EXPLICIT_PRIMARY_FP         */
                                       /*    AP_IMPLICIT_PRIMARY_FP         */
                                       /*    AP_BACKUP_FP                   */
                                       /*    AP_DEFAULT_PRIMARY_FP          */
                                       /*    AP_DEFAULT_BACKUP_FP           */
                                       /*    AP_DOMAIN_FP                   */
                                       /*    AP_HOST_FP                     */
                                       /*    AP_NO_FP                       */
    UCHAR  fp_status;                  /* focal point status                */
                                       /*    AP_NOT_ACTIVE                  */
                                       /*    AP_ACTIVE                      */
                                       /*    AP_PENDING                     */
                                       /*    AP_LOCAL_ACTIVE                */
                                       /*    AP_NEVER_ACTIVE                */
    UCHAR  fp_routing;                 /* focal point routing               */
                                       /*    AP_DEFAULT                     */
                                       /*    AP_DIRECT                      */
    UCHAR  pri_fp_fq_cp_name[17];      /* Primary Focal Point Name          */
                                       /*    (EBCDIC type A)                */
    UCHAR  reserv1;                    /* Reserved                          */
    USHORT num_backups;                /* Total number of backups           */
                                       /*    (only 1st displayed)           */

    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use ms_fp_entry_len to skip over them.                               */
    /************************************************************************/

} MS_FP_OVERLAY;

typedef struct ms_appl_overlay {       /* One each MS application Displayed */

  /**************************************************************************/
  /* The first ms_appl_overlay follows immediately after the last ms_fp     */
  /* overlay.  Hence, the address of the first ms_appl_overlay should be:   */
  /* the address of the last ms_fp_overlay + ms_fp_entry length.            */
  /* To find the next ms_appl_overlay, add:  ms_appl_entry_length.          */
  /**************************************************************************/

    ULONG  ms_appl_entry_len;          /* Size of MS application info       */
    UCHAR  ms_appl_name[8];            /* MS Application name               */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  ms_category[8];             /* MS Category                       */
                                       /* 0 or 4 byte SNA Defined Category  */
    UCHAR  q_name[81];                 /* OS/2 Queue Name (ASCIIZ)          */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  reserv5;                    /* Reserved                          */

    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use ms_appl_entry_len to skip over them.                             */
    /************************************************************************/

} MS_APPL_OVERLAY;

typedef struct ms_act_trans_overlay  { /* One each MS active trans Displayed*/

  /**************************************************************************/
  /* The first ms_act_trans_overlay follows immediately after the last      */
  /* ms_appl overlay.  Hence, the address of the first ms_act_trans_overlay */
  /* should be:                                                             */
  /*  the address of the last ms_appl_overlay + ms_appl_entry length.       */
  /* To find the next ms_act_trans_overlay, add:  ms_act_trans_entry_length.*/
  /**************************************************************************/

    ULONG  ms_act_trans_entry_len;     /* Size of info                      */
    UCHAR  fq_origin_cp_name[17];      /* Fully Qualified Origin CP Name    */
                                       /*    (EBCDIC type A)                */
    UCHAR  origin_ms_appl_name[8];     /* Origin MS Application Name        */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  fq_dest_cp_name[17];        /* Fully Qualified Dest. CP Name     */
                                       /*    (EBCDIC type A)                */
    UCHAR  dest_ms_appl_name[8];       /* Dest. MS Application Name         */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */

    /************************************************************************/
    /* the following 3 fields are part of the Unit of Work (UOW)            */
    /************************************************************************/

    UCHAR  fq_req_loc_cp_name[17];     /* Requester Location                */
                                       /*    (EBCDIC type A)                */
    UCHAR  req_agent_appl_name[8];     /* Requester Application Name        */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  seq_num_dt[15];             /* Sequence Number / date - time     */

    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use ms_act_trans_entry_len to skip over them.                        */
    /************************************************************************/

} MS_ACT_TRANS_OVERLAY;

typedef struct ms_local_fp_overlay {   /* One each Local FP disp            */

  /**************************************************************************/
  /* The first ms_local_fp_overlay follows immediately after the last       */
  /* ms_act_trans_overlay.  Hence, the address of the first                 */
  /* ms_local_fp_overlay should be:                                         */
  /*  the address of the last ms_act_trans_overlay + ms_act_trans_entry_len.*/
  /* To find the next ms_local_fp_overlay, add: ms_local_fp_entry_len.      */
  /**************************************************************************/

    ULONG  ms_local_fp_entry_len;      /* Size of MS local FP entry         */
    ULONG  ms_local_fp_info_len;       /* Size of MS local FP info          */
    UCHAR  ms_appl_name[8];            /* MS Application name               */
                                       /*    4 byte SNA Defined             */
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  ms_category[8];             /* MS Category                       */
                                       /* 0 or 4 byte SNA Defined Ctgy      */
    UCHAR  appl_status;                /* status of local FP appl           */
                                       /*    AP_APPL_UNREGISTERED           */
                                       /*    AP_APPL_REGISTERED             */
                                       /*    AP_APPL_REG_Q_PROB             */
    UCHAR  default_soc;                /* Default sphere of control?        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  dflt_bkup_fp_fq_cp_name[17];/* Backup Focal Point Name           */
                                       /*    (EBCDIC type A)                */
    UCHAR  dflt_bkup_ind;              /* Replace Backup FP indicator       */
                                       /*    AP_REPLACE_BACKUP_FP           */
                                       /*    AP_KEEP_BACKUP_FP              */
    USHORT num_soc_nodes;              /* number of soc entries             */

    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use ms_local_fp_entry_len to skip over them.                         */
    /************************************************************************/

} MS_LOCAL_FP_OVERLAY;                 /*                                   */

typedef struct ms_soc_overlay {        /* One each Local FP disp            */

  /**************************************************************************/
  /* There are some number of ms_soc_overlay's for each                     */
  /* ms_local_fp_overlay.                                                   */
  /*                                                                        */
  /* The first ms_soc_overlay follows immediately after the                 */
  /* ms_local_fp_overlay.  Hence, the address of the first                  */
  /* ms_soc_overlay should be:                                              */
  /*  the address of the ms_local_fp_overlay +                              */
  /*                     sizeof(ms_local_fp_entry_len) +                    */
  /*                     ms_local_fp_info_len                               */
  /* To find the next ms_soc_overlay, add:  ms_soc_entry_len                */
  /**************************************************************************/

    ULONG  ms_soc_entry_len;           /* Size of MS local FP info          */
    UCHAR  soc_entry_fq_cp_name[17];   /* Soc entry name                    */
                                       /*    (EBCDIC type A)                */
    UCHAR  expl_bkup_fp_fq_cp_name[17];/* Backup Focal Point Name           */
                                       /*    (EBCDIC type A)                */
    UCHAR  expl_bkup_ind;              /* Replace Backup FP indicator       */
                                       /*    AP_REPLACE_BACKUP_FP           */
                                       /*    AP_KEEP_BACKUP_FP              */
    UCHAR  soc_entry_status;           /* Status of soc entry               */
                                       /*    AP_REVOKED                     */
                                       /*    AP_INACT_EXP                   */
                                       /*    AP_INACT_DEF                   */
                                       /*    AP_INACT_IMP                   */
                                       /*    AP_ADD_PND                     */
                                       /*    AP_ACTIVE_SOC                  */
                                       /*    AP_DLT_ADD_PND                 */
                                       /*    AP_DLT_PND                     */
    UCHAR  soc_entry_rank;             /* how acquired                      */
                                       /*    AP_EXPLICIT_PRIMARY_FP         */
                                       /*    AP_IMPLICIT_PRIMARY_FP         */
                                       /*    AP_BACKUP_FP                   */
                                       /*    AP_DEFAULT_PRIMARY_FP          */
                                       /*    AP_DEFAULT_BACKUP_FP           */
                                       /*    AP_NO_FP                       */
    UCHAR  reserv1;
    /************************************************************************/
    /* Additional fields of unspecified length are located in this position.*/
    /* Use ms_soc_entry_len to skip over them.                              */
    /************************************************************************/

} MS_SOC_OVERLAY;                      /*                                   */

typedef struct pu_info_sect {          /* Number of PUs displayed + size    */

  /**************************************************************************/
  /* The address of this structure should be: pu_info_ptr                   */
  /**************************************************************************/

    ULONG  pu_init_sect_len;           /* Structure length                  */
    USHORT num_pu;                     /* Number of PUs Displayed           */
    USHORT total_pu;                   /* Total Number PUs                  */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} PU_INFO_SECT;

typedef struct pu_overlay {            /* One for each pu displayed         */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /*       pu_info_ptr + pu_info_ptr->pu_init_sect_len.                     */
  /* To find the next one, add:    pu_overlay_ptr->entry_len                */
  /**************************************************************************/

    ULONG  entry_len;                  /* Size of pu info                   */
    ULONG  pu_overlay_len;             /* This value contains the size      */
                                       /* of the pu_overlay structure only  */
    UCHAR  pu_name[8];                 /* PU Name (EBCDIC type A)           */
    UCHAR  pu_node_id[4];              /* PU Node ID (used on XID)          */
    UCHAR  link_name[8];               /* Link Name (EBCDIC type A)         */
    USHORT nbr_lus;                    /* Number of LUs active              */
    UCHAR  adj_fq_cp_name[17];         /* Adj CP Name (EBCDIC Type A)       */
    UCHAR  pu_status;                  /* PU Status                         */
                                       /*    AP_SESS_INACTIVE               */
                                       /*    AP_SESS_PENDING_ACTIVE         */
                                       /*    AP_SESS_ACTIVE                 */
                                       /*    AP_SESS_PENDING_INACTIVE       */
                                       /*    AP_SESS_PENDING_TAKEOVER       */
    UCHAR  dlc_name[8];                /* Name of DLC used for link         */
    UCHAR  sddlu_enabled;              /* SDDLU enabled for this PU?        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  dedicated_pu;               /* Dedicated PU?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  backup_host_link[8];        /* backup host link name (EBCDIC -A) */
    UCHAR  backup_active;              /* backup host active                */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv1[1];                 /* reserved                          */
    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} PU_OVERLAY;

typedef struct pulu_overlay {

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /*       pu_info_ptr + pu_info_ptr->pu_overlay_len                        */
  /* To find the next one, add:    pulu_overlay_ptr->entry_len              */
  /**************************************************************************/
    ULONG  entry_len;                  /* Length of this entry              */
    UCHAR  lu_name[8];                 /* LU Name                           */
    UCHAR  lu_type;                    /* LU Type                           */
                                       /*    AP_LU0                         */
                                       /*    AP_LU1                         */
                                       /*    AP_LU2                         */
                                       /*    AP_LU3                         */
                                       /*    AP_LU62                        */
                                       /*    AP_UNKNOWN                     */
                                       /*    AP_GW_LU0                      */
                                       /*    AP_GW_LU1                      */
                                       /*    AP_GW_LU2                      */
                                       /*    AP_GW_LU3                      */
                                       /*    AP_GW_LU62                     */
                                       /*    AP_GW_UNKNOWN                  */
    UCHAR  lu_status;                  /* LU Status                         */
                                       /*    AP_SESS_ACTIVE                 */
                                       /*    AP_SESS_INACTIVE               */
    UCHAR  link_name[8];               /* Link Name for Gateway LUs         */
    UCHAR  dlc_name[8];                /* DLC Name for Gateway LUs          */
} PULU_OVERLAY;


typedef struct node_info_sect        /*   One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: node_info_ptr                 */
  /**************************************************************************/

{
    UCHAR  route_resist;               /* Route Addition Resistance         */
                                       /*    0-255                          */
    UCHAR  reserv3;                    /* Reserved                          */
    USHORT max_cache;                  /* Max number of resources that can  */
                                       /* be cached in the directory 0 =    */
                                       /* no maximum                        */
                                       /*    1-65535                        */
    USHORT current_cache;              /* current number of entries in the  */
                                       /* in the directory cache            */
    USHORT dir_dump_interval;          /* how often the dir is  saved on    */
                                       /* perm storage 0 = never saved      */
                                       /* 1-65535 = number of updates       */
                                       /* before saving                     */
    USHORT max_compression_tokens ;    /* Maximum amount of resources       */
                                       /* which can be dedicated            */
                                       /* to data compression               */
    USHORT tokens_remaining ;          /* The amount of resources           */
                                       /* still available to dedicate       */
                                       /* to compression                    */
    UCHAR  max_compression_level ;     /* Maximum compression algorithm     */
                                       /* which will be used for sessions   */
                                       /* with this node.                   */
                                       /* 0 = NO compression                */
                                       /* 1 = RLE compression               */
                                       /* 2 = LZ9 compression               */


    /************************************************************************/
    /*      Additional fields may be added here in future releases          */
    /************************************************************************/

} NODE_INFO_SECT;

typedef struct directory_info_sect   /*   One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: directory_info_ptr            */
  /**************************************************************************/

{
    ULONG  directory_init_sect_len;    /* Struct length                     */
    USHORT num_entries;                /* Number of dir entries             */
    USHORT num_nns;                    /* number network nodes displayed    */
    USHORT total_nns;                  /* total number of network nodes     */
    USHORT num_ens;                    /* number of end nodes displayed     */
    USHORT total_ens;                  /* total number of end nodes         */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} DIRECTORY_INFO_SECT;

typedef struct dir_nn_overlay        /*   One for each NN Displayed         */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* directory_info_ptr + directory_info_ptr->directory_init_sect_len. To   */
  /* find the next one, add: dir_nn_entry_len                               */
  /**************************************************************************/

{
    ULONG  dir_nn_entry_len;           /* Size of all nn data               */
    ULONG  dir_nn_info_len;            /* size of nn data only              */
    UCHAR  fq_nncp_name[17];           /* FQ NNCP Name SERVING  (EBCDIC)    */
    UCHAR  reserv3;                    /* Reserved                          */
    USHORT num_lus;                    /* number of lus displayed           */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} DIR_NN_OVERLAY;

typedef struct dir_en_overlay        /*   One for each EN Displayed         */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* lun_overlay of the last NN + lun_entry_len.                            */
  /* To find the next one, add: dir_en_entry_len                            */
  /**************************************************************************/

{
    ULONG  dir_en_entry_len;           /* Size of all nn data               */
    ULONG  dir_en_info_len;            /* size of nn data only              */
    UCHAR  fq_encp_name[17];           /* End Node CP FQ name   (EBCDIC)    */
    UCHAR  reserv3;                    /* Reserved                          */
    USHORT num_lus;                    /* number of lus displayed           */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} DIR_EN_OVERLAY;

typedef struct lun_overlay           /*   one for each lu of the NN or EN   */
  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the current dir_nX_overlay + dir_nX_info_len + sizeof(dir_nX_entry_len)*/
  /* To find the next lun overlay, add: lun_entry_len.                      */
  /**************************************************************************/

{
    ULONG  lun_entry_len;              /* Size of all lun data              */
    UCHAR  fqlu_name[17];              /* fully qualified lu name (EBCDIC)  */
    UCHAR  fq_nncp_name[17];           /* Fully qual owning cp    (EBCDIC)  */
    UCHAR  lu_entry_type;              /* type of dir entry                 */
                                       /*    AP_HOME                        */
                                       /*    AP_REGISTER                    */
                                       /*    AP_CACHE                       */
    UCHAR  wildcard_entry;             /* Wildcard Entry?                   */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  dlur_entry;                 /* DLUR Lu Entry?                    */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv1[3];                 /* reserved allignment               */
} LUN_OVERLAY;

typedef struct topology_info_sect      /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: topology_info_ptr             */
  /**************************************************************************/

{
    ULONG  topology_init_sect_len;     /* Struct length                     */
    USHORT num_nns;                    /* number network nodes DISPLAYED    */
    USHORT total_nns;                  /* total number of nn's              */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} TOPOLOGY_INFO_SECT;

typedef struct topology_nn_overlay     /* One for each NN Displayed         */

  /**************************************************************************/
  /* The address of the first of these structures should be:                */
  /* topology_info_ptr + topology_info_ptr->topology_init_sect_len. To find */
  /* the next one, add: topology_entry_len                                  */
  /**************************************************************************/

{
    ULONG  topology_entry_len;         /* Size of all nn data               */
    ULONG  topology_nn_info_len;       /* size of nn data only              */
    UCHAR  fq_nncp_name[17];           /* FQ NNCP name                      */
    UCHAR  route_resist;               /* Route Addition Resistance         */
                                       /*    0-255                          */
    UCHAR  nncp_congested;             /* Congested?                        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  nncp_quiescing;             /* Quiescing?                        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  nncp_isr_depleted;          /* ISR Depleted?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    USHORT  num_tgs;                   /* Number of TGs returned            */
    UCHAR  node_time_remaining;        /* Days before garbage collection    */
    UCHAR  node_garbage_collect;       /* Node to be garbage collected?     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  node_hpr_lvl;               /* Node HPR level                    */
                                       /*    AP_NONE                        */
                                       /*    AP_ANR                         */
                                       /*    AP_RTP                         */
                                       /*    AP_CONTROL_FLOWS_OVER_RTP      */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} TOPOLOGY_NN_OVERLAY;

typedef struct tg_overlay              /* one for each tg of the NN Dsplyd  */
  /**************************************************************************/
  /* The address of the first of tg overlay should be:                      */
  /*   The address of the current topology_nn_overlay +                     */
  /*   topology_nn_info_len +                                               */
  /*   sizeof(topology_entry_len)                                           */
  /* To find the next tg overlay, add: tg_entry_len.                        */
  /**************************************************************************/

{
    ULONG  tg_entry_len;               /* Size of all TG data               */
    UCHAR  fq_nncp_name[17];           /* Adjacent CP Name                  */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  tg_number;                  /* TG Number 0-240                   */
    UCHAR  node_type;                  /* Node Type                         */
                                       /*    AP_REAL                        */
                                       /*    AP_VIRTUAL                     */
    UCHAR  eff_capacity;               /* Effective Capacity                */
    UCHAR  conn_cost;                  /* Cost Per Connect Time             */
    UCHAR  byte_cost;                  /* Cost Per Byte                     */
    UCHAR  propagation_delay;          /* Propagation Delay                 */
                                       /*    AP_PROP_DELAY_MINIMUM          */
                                       /*    AP_PROP_DELAY_LAN              */
                                       /*    AP_PROP_DELAY_TELEPHONE        */
                                       /*    AP_PROP_DELAY_PKT_SWITCHED_NET */
                                       /*    AP_PROP_DELAY_SATELLITE        */
                                       /*    AP_PROP_DELAY_MAXIMUM          */
    UCHAR  user_def_1;                 /* User Defined 1                    */
    UCHAR  user_def_2;                 /* User Defined 2                    */
    UCHAR  user_def_3;                 /* User Defined 3                    */
    UCHAR  security;                   /* Security                          */
                                       /*    AP_SEC_NONSECURE               */
                                       /*    AP_SEC_PUBLIC_SWITCHED_NETWORK */
                                       /*    AP_SEC_UNDERGROUND_CABLE       */
                                       /*    AP_SEC_SECURE_CONDUIT          */
                                       /*    AP_SEC_GUARDED_CONDUIT         */
                                       /*    AP_SEC_ENCRYPTED               */
                                       /*    AP_SEC_GUARDED_RADIATION       */
    UCHAR  quiescing;                  /* Quiescing?                        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  network_topology;           /* Is this in Network Topology?      */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  tg_time_remaining;          /* Days before garbage collection    */
    UCHAR  tg_garbage_collect;         /* TG to be garbage collected?       */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  hpr_enabled;                /* HPR enabled on this link          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  adj_node_rtp_lvl;           /* Adjacent Node RTP level           */
                                       /*    AP_NONE                        */
                                       /*    AP_RTP                         */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/
} TG_OVERLAY;

typedef struct isr_info_sect           /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: isr_info_ptr                  */
  /**************************************************************************/

{
    ULONG  isr_init_sect_len;          /* Struct length                     */
    USHORT num_isr;                    /* Num Intermediate Sess. Displayed  */
    USHORT total_isr;                  /* Total Intermediate Sessions       */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} ISR_INFO_SECT;

typedef struct isr_overlay             /* One for each isr Displayed        */

  /**************************************************************************/
  /* The address of the first of these structures should be: isr_info_ptr + */
  /* isr_info_ptr->isr_init_sect_len.  To find the next one, add:           */
  /* isr_entry_len                                                          */
  /**************************************************************************/

{
    ULONG  isr_entry_len;              /* Size of all isr data              */
    UCHAR  fq_pri_nncp_name[17];       /* FQ NNCP name        (EBCDIC)      */
    UCHAR  fq_sec_nncp_name[17];       /* FQ NNCP name        (EBCDIC)      */
    UCHAR  pri_link_name[8];           /* Primary Link Name   (EBCDIC)      */
    UCHAR  sec_link_name[8];           /* Secondary Link Name (EBCDIC)      */
    FQPCID_OVERLAY fqpcid;             /* Fully Qualified Procedure         */
                                       /* Correlation Identifier            */
    UCHAR  fq_pri_lu_name[17];         /* Name of primary LU                */
    UCHAR  fq_sec_lu_name[17];         /* Name of secondary LU              */
    UCHAR  pri_lu_send_fmd_piu_count[8];
                                       /* FMD PIU count sent by Pri. LU     */
    UCHAR  sec_lu_send_fmd_piu_count[8];
                                       /* FMD PIU count sent by Sec. LU     */
    UCHAR  pri_lu_send_non_fmd_piu_count[8];
                                       /* Non-FMD PIU count sent by Pri. LU */
    UCHAR  sec_lu_send_non_fmd_piu_count[8];
                                       /* Non-FMD PIU count sent by Sec. LU */
    UCHAR  pri_lu_send_byte_count[8];  /* Bytes sent on session by Pri. LU  */
    UCHAR  sec_lu_send_byte_count[8];  /* Bytes sent on session by Sec. LU  */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} ISR_OVERLAY;

typedef struct cos_info_sect           /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: cos_info_ptr                  */
  /**************************************************************************/

{
    ULONG  cos_init_sect_len;          /* Struct length                     */
    USHORT num_cos;                    /* Number COS Definitions Displayed  */
    USHORT total_cos;                  /* Total Number of COS Definitions   */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} COS_INFO_SECT;

typedef struct cos_overlay             /* One for each cos def              */

  /**************************************************************************/
  /* The address of the first of these structures should be: cos_info_ptr + */
  /* cos_info_ptr->cos_init_sect_len.  To find the next one, add:           */
  /* cos_entry_len                                                          */
  /**************************************************************************/

{
    ULONG  cos_entry_len;              /* Size of all cos data              */
    ULONG  cos_info_len;               /* size of cos data only             */
    UCHAR  cos_name[8];                /* COS name                          */
    UCHAR  trans_priority;             /* Transmission Priority             */
                                       /*    AP_NETWORK                     */
                                       /*    AP_HIGH                        */
                                       /*    AP_MEDIUM                      */
                                       /*    AP_LOW                         */
    UCHAR  num_of_node_rows;           /* number of node rows 1-8           */
    UCHAR  num_of_tg_rows;             /* number of tg rows 1-8             */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} COS_OVERLAY;

typedef struct cos_node_row_overlay    /* one for each cos node row         */

  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the current cos_overlay + cos_info_len + sizeof(cos_entry_len)         */
  /* To find the next cos node row, add: cos_node_row_entry_len.            */
  /**************************************************************************/
{
    ULONG  cos_node_row_entry_len;     /* Size of all cos node row data     */
    UCHAR  weight;                     /* Node Row Weight                   */
                                       /*    0-255                          */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  route_add_res_min;          /* Route Addition Resistance Min     */
                                       /*    0-255                          */
    UCHAR  route_add_res_max;          /* Route Addition Resistance Max     */
                                       /*    0-255                          */
    UCHAR  congestion_min;             /* Congestion Min                    */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  congestion_max;             /* Congestion Max                    */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} COS_NODE_ROW_OVERLAY;

typedef struct cos_tg_row_overlay      /* one for each cos tg row           */

  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the last cos_node_row_overlay + cos_node_row_entry_len.                */
  /* (The first tg row overlay comes right after the last node row overlay) */
  /*                                                                        */
  /* To find the next cos tg row, add: cos_tg_row_entry_len.                */
  /**************************************************************************/
{
    ULONG  cos_tg_row_entry_len;       /* Size of all cos tg now data       */
    UCHAR  weight;                     /* TG Row Weight                     */
                                       /*    0-255                          */
    UCHAR  reserv3;                    /* Reserved                          */
    UCHAR  eff_capacity_min;           /* Effective Capacity Min            */
    UCHAR  eff_capacity_max;           /* Effective Capacity Max            */
                                       /*    1 byte floating point number   */
                                       /*       5 bit exponent              */
                                       /*       3 bit mantissa              */
    UCHAR  cost_per_time_min;          /* Cost Per Connect Min              */
                                       /*    0-255                          */
    UCHAR  cost_per_time_max;          /* Cost Per Connect Max              */
                                       /*    0-255                          */
    UCHAR  cost_per_byte_min;          /* Cost Per Byte Min                 */
                                       /*    0-255                          */
    UCHAR  cost_per_byte_max;          /* Cost Per Byte Min                 */
                                       /*    0-255                          */

    UCHAR  security_min;               /* Security Min                      */
    UCHAR  security_max;               /* Security Max                      */
                                       /*    AP_SEC_NONSECURE               */
                                       /*    AP_SEC_PUBLIC_SWITCHED_NETWORK */
                                       /*    AP_SEC_UNDERGROUND_CABLE       */
                                       /*    AP_SEC_SECURE_CONDUIT          */
                                       /*    AP_SEC_GUARDED_CONDUIT         */
                                       /*    AP_SEC_ENCRYPTED               */
                                       /*    AP_SEC_GUARDED_RADIATION       */
                                       /*    AP_SEC_MAXIMUM                 */

    UCHAR  propagation_delay_min;      /* Propagation Delay Min             */
    UCHAR  propagation_delay_max;      /* Propagation Delay Max             */
                                       /*    AP_PROP_DELAY_MINIMUM          */
                                       /*    AP_PROP_DELAY_LAN              */
                                       /*    AP_PROP_DELAY_TELEPHONE        */
                                       /*    AP_PROP_DELAY_PKT_SWITCHED_NET */
                                       /*    AP_PROP_DELAY_SATELLITE        */
                                       /*    AP_PROP_DELAY_MAXIMUM          */


    UCHAR  user_def_1_min;             /* User Defined 1 Min                */
    UCHAR  user_def_1_max;             /* User Defined 1 Max                */
    UCHAR  user_def_2_min;             /* User Defined 2 Min                */
    UCHAR  user_def_2_max;             /* User Defined 2 Max                */
    UCHAR  user_def_3_min;             /* User Defined 3 Min                */
    UCHAR  user_def_3_max;             /* User Defined 3 Max                */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} COS_TG_ROW_OVERLAY;

typedef struct cn_info_sect            /* One of these                      */

  /**************************************************************************/
  /* The address of this structure should be: cn_info_ptr                   */
  /**************************************************************************/

{
    ULONG  cn_init_sect_len;           /* Struct length                     */
    USHORT num_cn;                     /* number CN definitions displayed   */
    USHORT total_cn;                   /* total number of CN definitions    */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} CN_INFO_SECT;

typedef struct cn_overlay              /* One for each cn def               */

  /**************************************************************************/
  /* The address of the first of these structures should be: cn_info_ptr +  */
  /* cn_info_ptr->cn_init_sect_len.  To find the next one, add:             */
  /* cn_entry_len                                                           */
  /**************************************************************************/

{
    ULONG  cn_entry_len;               /* Size of all cn data               */
    ULONG  cn_info_len;                /* size of cn data only              */
    UCHAR  cn_name[17];                /* Connection Network Name           */
    UCHAR  cn_lim_res;                 /* Free Unused cn links              */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv6[4];                 /* Reserved                          */
    UCHAR  conn_cost;                  /* Cost Per Connect Time             */
    UCHAR  byte_cost;                  /* Cost Per Byte                     */
    UCHAR  propagation_delay;          /*    AP_PROP_DELAY_MINIMUM          */
                                       /*    AP_PROP_DELAY_LAN              */
                                       /*    AP_PROP_DELAY_TELEPHONE        */
                                       /*    AP_PROP_DELAY_PKT_SWITCHED_NET */
                                       /*    AP_PROP_DELAY_SATELLITE        */
                                       /*    AP_PROP_DELAY_MAXIMUM          */
    UCHAR  user_def_1;                 /* User Defined 1                    */
    UCHAR  user_def_2;                 /* User Defined 2                    */
    UCHAR  user_def_3;                 /* User Defined 3                    */
    UCHAR  security;                   /* Security                          */
                                       /*    AP_SEC_NONSECURE               */
                                       /*    AP_SEC_PUBLIC_SWITCHED_NETWORK */
                                       /*    AP_SEC_UNDERGROUND_CABLE       */
                                       /*    AP_SEC_SECURE_CONDUIT          */
                                       /*    AP_SEC_GUARDED_CONDUIT         */
                                       /*    AP_SEC_ENCRYPTED               */
                                       /*    AP_SEC_GUARDED_RADIATION       */
    UCHAR  reserv4;                    /* Reserved                          */
    UCHAR  num_adapters;               /* Number of adapters for this CN    */
    UCHAR  reserv5;                    /* Reserved                          */
    ULONG  eff_capacity;               /* Effective Capacity                */
                                       /*    0 | 1200 | 2400 | ...          */
                                       /*    ... | 16M | ...                */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} CN_OVERLAY;

typedef struct cna_overlay             /* One for each CN Adapter           */

  /**************************************************************************/
  /* The address of the first of these structures should be: The address of */
  /* the current cn_overlay + cn_info_len + sizeof(cn_entry_len)            */
  /* To find the next connection network adapter, add: cna_entry_len.       */
  /**************************************************************************/

{
    ULONG  cna_entry_len;              /* Size of all cn adapter data       */
    UCHAR  dlc_name[8];                /* DLC name (ASCII)                  */
    UCHAR  adapter_num;                /* DLC adapter number                */
    UCHAR  reserv3;                    /* Reserved                          */

    /************************************************************************/
    /* Additional fields may be added here in future releases               */
    /************************************************************************/

} CNA_OVERLAY;


/****************************************************************************/
/*                                                                          */
/*         Structures for REGISTER_MS_APPLICATION verb                      */
/*                                                                          */
/****************************************************************************/

typedef struct register_ms_application {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_REGISTER_MS_APPLICATION     */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  ms_appl_name[8];            /* MS Application name               */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  ms_category[8];             /* MS Category                       */
                                       /*  0 or 4 byte SNA Defined Category */
    USHORT segment_selector;           /* OS/2 16-bit Segment Selector      */
    UCHAR  reserv4[2];                 /* Reserved                          */
    UCHAR  *shared_mem;                /* OS/2 32-bit shared memory ptr.    */
    UCHAR  q_name[81];                 /* OS/2 Queue Name (ASCIIZ)          */
    UCHAR  ms_fp_appl;                 /* Focal point application?          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv5;                    /* Reserved                          */
    UCHAR  reserv6[33];                /* Reserved                          */
} REGISTER_MS_APPLICATION;


typedef struct unregister_ms_application {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_UNREGISTER_MS_APPLICATION   */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UCHAR  ms_appl_name[8];            /* MS Application name               */
                                       /*    4 byte SNA Defined MS Appl Name*/
                                       /* or 1-8 byte (EBCDIC type A)       */
    UCHAR  ms_category[8];             /* MS Category                       */
                                       /* 0 or 4 byte SNA Defined Category  */
    UCHAR  reserv4[32];                /* reserved                          */
} UNREGISTER_MS_APPLICATION;


typedef struct send_mds_mu {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_SEND_MDS_MU                 */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    UINT   reserv4:3;                  /* Bits 5-7                          */
                                       /* Reserved                          */
    UINT   mds_mu_routing:1;           /* Bit 4                             */
                                       /* Routing type?                     */
                                       /*    AP_DEFAULT                     */
                                       /*    AP_DIRECT                      */
    UINT   local_logging:1;            /* Bit 3                             */
                                       /* Local Logging?                    */
                                       /*    AP_LOG                         */
                                       /*    AP_NO_LOG                      */
    UINT   reserv5:1;                  /* Bit 2                             */
    UINT   product_set_id_subvector:1; /* Bit 1                             */
                                       /* Product Set ID Subvector?         */
                                       /*    AP_ADD                         */
                                       /*    AP_NO_ADD                      */
    UINT   time_stamp_subvector:1;     /* Bit 0                             */
                                       /* Time Stamp Subvector?             */
                                       /*    AP_ADD                         */
                                       /*    AP_NO_ADD                      */
    UINT   reserv6:8;                  /* Bits 8-15                         */
    UCHAR  origntr_id[8];              /* Originator ID                     */
                                       /*   (0 if unknown)                  */
    UCHAR  reserv7[2];                 /* Reserve                           */
    ULONG  dlen;                       /* Data Length                       */
    UCHAR  *dptr;                      /* Data Pointer                      */
    UCHAR  reserv8[32];                /* Reserve                           */
} SEND_MDS_MU;


typedef struct display {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_DISPLAY                     */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    ULONG  init_sect_len;              /* Length of this section            */
                                       /*  AP_INIT_SECT_LEN                 */
    ULONG  buffer_len;                 /* Length of passed buffer           */
    UCHAR  *buffer_ptr;                /* Passed address                    */
    ULONG  num_sections;               /* Number of sections                */
                                       /*  AP_NUM_SECTIONS                  */
    ULONG  display_len;                /* Returned, length used             */
    ULONG  area_needed;                /* Returned, length required         */
    UCHAR  sna_global_info;            /* SNA global info?                  */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  lu62_info;                  /* LU 6.2 info?                      */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  am_info;                    /* Attach Manager info?              */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  tp_info;                    /* TP info?                          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  sess_info;                  /* Session info?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  link_info;                  /* Link info?                        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  lu_0_3_info;                /* LU 0, 1, 2, & 3 info?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  gw_info;                    /* Gateway info?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  x25_physical_link_info;     /* X.25 info?                        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  sys_def_info;               /* System Default info?              */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  adapter_info;               /* Adapter info?                     */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  lu_def_info;                /* LU definition info?               */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  plu_def_info;               /* Remote LU def info?               */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  mode_def_info;              /* Mode Definition info?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  link_def_info;              /* Link Definition info?             */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  ms_info;                    /* Management Services info?         */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  pu_info;                    /* Physical Unit info?               */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  icas_info;                  /* Incoming Call Auto-answer Status  */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  reserv4[2];                 /* Reserved                          */
    /* Returned Pointers */

    /* Note that the address of the first of these pointers is */
    /*    address of the verb control block + init_sect_len    */

    SNA_GLOBAL_INFO_SECT          *sna_global_info_ptr;
    LU62_INFO_SECT                *lu62_info_ptr;
    AM_INFO_SECT                  *am_info_ptr;
    TP_INFO_SECT                  *tp_info_ptr;
    SESS_INFO_SECT                *sess_info_ptr;
    LINK_INFO_SECT                *link_info_ptr;
    LU_0_3_INFO_SECT              *lu_0_3_info_ptr;
    GW_INFO_SECT                  *gw_info_ptr;
    X25_PHYSICAL_LINK_INFO_SECT   *x25_physical_link_info_ptr;
    SYS_DEF_INFO_SECT             *sys_def_info_ptr;
    ADAPTER_INFO_SECT             *adapter_info_ptr;
    LU_DEF_INFO_SECT              *lu_def_info_ptr;
    PLU_DEF_INFO_SECT             *plu_def_info_ptr;
    MODE_DEF_INFO_SECT            *mode_def_info_ptr;
    LINK_DEF_INFO_SECT            *link_def_info_ptr;
    MS_INFO_SECT                  *ms_info_ptr;
    PU_INFO_SECT                  *pu_info_ptr;
    ICAS_INFO_SECT                *icas_info_ptr;
} DISPLAY;


typedef struct display_appn {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_DISPLAY_APPN                */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    ULONG  init_sect_len;              /* Length of this section            */
                                       /*  APPN_INIT_SECT_LEN               */
    ULONG  buffer_len;                 /* Length of passed buffer           */
    UCHAR  *buffer_ptr;                /* Passed address                    */
    ULONG  num_sections;               /* Number of sections                */
                                       /*  APPN_NUM_SECTIONS                */
    ULONG  display_len;                /* Returned, length used             */
    ULONG  area_needed;                /* Returned, length required         */
    UCHAR  node_info;                  /* Node info?                        */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  directory_info;             /* Directory info?                   */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  topology_info;              /* Topology info?                    */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  isr_info;                   /* Intermediate Sessions?            */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  cos_info;                   /* Class of Service info?            */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR  cn_info;                    /* Connection Network info?          */
                                       /*    AP_NO                          */
                                       /*    AP_YES                         */
    UCHAR reserv4[2];                  /*   Reserved                        */

    /* Note that the address of the first of these pointers is */
    /*    address of the verb control block + init_sect_len    */

    /* Returned Pointers */

    NODE_INFO_SECT                *node_info_ptr;
    DIRECTORY_INFO_SECT           *directory_info_ptr;
    TOPOLOGY_INFO_SECT            *topology_info_ptr;
    ISR_INFO_SECT                 *isr_info_ptr;
    COS_INFO_SECT                 *cos_info_ptr;
    CN_INFO_SECT                  *cn_info_ptr;
} DISPLAY_APPN;


typedef struct set_discovery_server {
    USHORT opcode;                     /* Verb operation code               */
                                       /*    AP_SET_DISC_SERV               */
    UCHAR  reserv1[6];                 /* Reserved                          */
    USHORT primary_rc;                 /* Primary RETURN_CODE               */
    UCHAR  reserv2[2];                 /* Reserved                          */
    ULONG  secondary_rc;               /* Secondary RETURN_CODE             */
    UCHAR  reserv3[4];                 /* Reserved                          */
    ULONG  status;                     /* Enable/Disable switch             */
                                       /*    AP_ENABLE_DISCOVERY            */
                                       /*    AP_DISABLE_DISCOVERY           */
    ULONG  adapter_num;                /* Logical adapter number or         */
                                       /*    AP_ALL_ADAPTERS                */
    ULONG  routing_capability;         /* Routing capability                */
                                       /*    AP_NN_SERVER and/or            */
                                       /*    AP_GATEWAY_SERVER              */
    ULONG  group_name_count;           /* Number of names 1 to 16           */
    /************************************************************************/
    /* The address of the first group name is:                              */
    /* set_discovery_server + sizeof(SET_DISCOVERY_SERVER).  To build the   */
    /* address of the next group name, add:                                 */
    /* sizeof(GROUP_NAME_OVERLAY). See struct group_name_overlay            */
    /* in APPCDEF.H.                                                        */
    /************************************************************************/
    UCHAR  reserv4[24];                /* Reserved                          */
} SET_DISCOVERY_SERVER;


#endif

#ifdef __cplusplus
  }
#endif
